<!--
 (C) COPYRIGHT International Business Machines Corp. 2012, 2015. All Rights Reserved
  US Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-->
<!--
$Archive: /epass/epass5.0.1/com/avinamart/WebInterface/public_html/Integration/xsl/gXML2ePASS/gXML2ePASS_Bid.xsl $
$Revision: 2 $ $Date: 10/14/04 3:46p $
    Description: XSL code to transform generic speadsheet XML into ePASS XML Bids related element.
    Author: Xiaocun Xu
-->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0"
    xmlns:saxon="http://saxon.sf.net/"
    xmlns:java="java:com.avinamart.Utility.EPASSIFHelper"
    exclude-result-prefixes="saxon java"  extension-element-prefixes="saxon">

    <!-- **************************************************** -->
    <!-- RFx section specific for converting to ePASS Bid XML -->
    <!-- **************************************************** -->

    <!-- find the organization id. The first element is OrganizationCode. -->
    <xsl:variable name="bidtemplate.orgcode"
            select="book/sheet/range/row[cell[@column='1']=java:getValue($language,'excelmap.bids.rfx.OrganizationCode')][1]"/>

    <!-- find the rfx unique id. The first element is RFxCode. -->
    <xsl:variable name="bidtemplate.rfxcode"
            select="book/sheet/range/row[cell[@column='1']=java:getValue($language,'excelmap.bids.rfx.RFxCode')][1]"/>

    <!-- find the rfx type. The first element is RFxType. -->
    <xsl:variable name="bidtemplate.rfxtype"
            select="book/sheet[1]/range/row[cell[@column='1']=java:getValue($language,'excelmap.bids.rfx.RFxType')][1]"/>
            
    <xsl:variable name="bid.rfxtype" select="java:getName($language, $bidtemplate.rfxtype/cell[@column='2'], 'integration.AuctionType.')"/>
    
	<xsl:variable name="subName" select="java:getSubValue($language,book/sheet[1]/range/row[@row=$rfx.eventtype.position]/cell[@column='4'])"/>
    <xsl:variable name="bid.rfxtype1" select="java:getName($language,$subName, 'integration.AuctionType.')"/>
    
    <!-- Global variables while import for New Bid Templates are declared here -->
    <xsl:variable name="pleaseSelectValue" select="java:getValue($language,'form.terminology.select.no_selection_please_select')"/>

    <!-- find the bidding instructions. -->
    <!-- get the row number for template instruction. If the instructions are deleted from template then use the last row number-->
    <xsl:variable name="instrrow" select="number(book/sheet/range/row[cell[@column = '1'] = java:getValue($language, 'excelmap.base.template_instructions.TemplateInstructions')]/@row)" />
	<xsl:variable name="bidtemplate.instr.row">	    
		<xsl:choose>	    
		    <xsl:when test="string($instrrow) = 'NaN'">
		   	    <xsl:value-of select="number(book/sheet/range/row[last()]/@row)" />
		   	</xsl:when>
		   	<xsl:otherwise>
		   		<xsl:value-of select="$instrrow - 1" />
		   	</xsl:otherwise>
	   	</xsl:choose>
	</xsl:variable>
	
	<xsl:variable name="buyerside">
	  <xsl:choose>
		<xsl:when test="book/sheet/range/row[@row='6']/cell[@column='1'] = java:getValue($language,'excelmap.bids.rfx.RFxRoundDescription')">
			<xsl:value-of select="'true'"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="'false'"/>
		</xsl:otherwise>
	</xsl:choose>
   </xsl:variable>
    <!-- find the bid header row.  The first column contain "Item Infomation" -->
    <xsl:variable name="bidtemplate.bid.header.itemsection"
            select="book/sheet/range/row[cell[@column='1'] = java:getValue($language,'excelmap.bids.headers.item.info')]"/>
    <xsl:variable name="bidtemplate.bid.header.itemsectionRow" select="number($bidtemplate.bid.header.itemsection/@row)"/>
    
    <xsl:variable name="bidtemplate.bid.headerRow">
      <xsl:choose>
        <xsl:when test="($buyerside = 'true') or $poiBid='true'"><!-- If this is old(without validation) or csv template, Item name column is after two rows from 'Item Information' column-->
          <xsl:value-of select="$bidtemplate.bid.header.itemsectionRow + 2"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="$bidtemplate.bid.header.itemsectionRow + 1"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:variable name="bidtemplate.bid.header" select="book/sheet/range/row[@row = $bidtemplate.bid.headerRow]"/>
    
    <!-- RFXMG-START -->
    <!-- xsl:if test="book/sheet/range/row[cell[@column='1'] = java:getValue($language,'excelmap.bids.headers.section.volumediscountbids')]"-->
	    <xsl:variable name="bidtemplate.volumebid.header"
    			select="book/sheet/range/row[cell[@column='1']=java:getValue($language,'excelmap.bids.headers.section.volumediscountbids')][1]"/>
    	<xsl:variable name="bidtemplate.bundlebid.header"
    			select="book/sheet/range/row[cell[@column='1']=java:getValue($language, 'excelmap.bids.bundle.bundlebids')][1]"/>
    	<xsl:variable name="bidtemplate.volumebid.header.row" select="$bidtemplate.volumebid.header/@row"/>
    	<xsl:variable name="bidtemplate.bundlebid.header.row" select="$bidtemplate.bundlebid.header/@row"/>
    	<xsl:variable name="discountBidding">
    		<xsl:choose>
    			<xsl:when test="($bid.rfxtype = 'reverse') and
				    			($bidtemplate.bid.header[cell[@column='10']=java:getValue($language, 'excelmap.bids.line_items.LineItemDiscountType')])">
    				<xsl:value-of select="'true'"/>    				
    			</xsl:when>
    			<xsl:otherwise>
    				<xsl:value-of select="'false'"/>    				
    			</xsl:otherwise>
    		</xsl:choose>
    	</xsl:variable>
    <!-- /xsl:if -->
    <!-- RFXMG-END -->
    <!-- Get the row number of column containing "Item Name" in first column else row number which contain "TEMPLATE INSTRUCTIONS" in first column-->
    <xsl:variable name="bidtemplate.bid.header.row">
        <xsl:choose>
            <xsl:when test="$bidtemplate.bid.header">
                <xsl:value-of select="number($bidtemplate.bid.header/@row)"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$bidtemplate.instr.row"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>

    <!-- find the matrix response header row.  The fourth element is Field Label -->
    <!--For any row which 1st column contain string "Table Response"-->
    <xsl:variable name="bidtemplate.matrix" select="book/sheet/range/row[cell[@column='1']=$TableResponse][1]"/>


    <xsl:variable name="bidtemplate.matrix.row">
        <xsl:choose>
            <xsl:when test="$bidtemplate.matrix">
                <xsl:value-of select="number($bidtemplate.matrix/@row)"/><!--if matrix type questions are present in RFX-->
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$bidtemplate.bid.header.row"/> <!--if matrix type questions are absent in RFX-->
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>

    <!-- find the response header row.  The first element is ResponseQuestionnaire -->
    <xsl:variable name="bidtemplate.response.header"
            select="book/sheet/range/row[cell[@column='1']=java:getValue($language,'excelmap.bids.questions.ResponseQuestionnaire')][1]"/>
    <xsl:variable name="bidtemplate.response.header.row">
        <xsl:choose>
            <xsl:when test="$bidtemplate.response.header">
                <xsl:value-of select="number($bidtemplate.response.header/@row)"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$bidtemplate.instr.row"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>

    <!--contain true if "Buyer Response Submission Fields" is present in 12th column-->
    <xsl:variable name="org.response.buyer"
            select="book/sheet/range/row[cell[@column='12']=java:getValue($language,'excelmap.bids.headers.responder.info')][1]"/>

    <!--if "Buyer Response Submission Fields" is in 12th column then set value 15(15 because of 3 extra columns specific to buyer) else 12-->
    <xsl:variable name="org.response.offset">
        <xsl:choose>
            <xsl:when test="$org.response.buyer">
                <xsl:value-of select="number(15)"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="number(12)"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>

    <!--contain either value 12( if supplier bid template) or value 15 (if buyer bid template)-->
    <xsl:variable name="org.matrix.offset" select="$org.response.offset"/>

    <!-- offset based upon buyer/supplier import template -->
    <!-- IMPORTANT: CHANGE ME IF ITEM/BUYER FIELDS ALTERED: -->
    <!-- make these values reflect the number of fields to place as fixed in XML -->
    <xsl:variable name="org.bid.buyer"
            select="book/sheet/range/row[cell[@column='6']=java:getValue($language,'excelmap.bids.headers.buyer.info')][1]"/>
    <xsl:variable name="org.bid.offset">
        <xsl:choose> <!-- PR 60818 Localization of RFx type removed -->
        	<xsl:when test="($buyerside = 'false') and
        					(not($bid.rfxtype = 'reverse')) and
        					(not($bid.rfxtype = 'forward'))">
        		<xsl:value-of select="number(book/sheet/range/row[@row &lt; $bidtemplate.instr.row]/cell[.=java:getValue($language, 'excelmap.bids.bids.BidAction')]/@column)"/>
        	</xsl:when>
        	<xsl:when test="$buyerside = 'true'">
	    		<xsl:value-of select="number(book/sheet/range/row[@row = $bidtemplate.bid.headerRow]/cell[.=java:getValue($language, 'excelmap.bids.bids.BidAction')]/@column)"/>
	    	</xsl:when>
        	<xsl:when test="($buyerside = 'false') and
        					(($bid.rfxtype = 'reverse') or ($bid.rfxtype = 'forward'))">
        		<xsl:value-of select="number(book/sheet/range/row[@row='13']/cell[.=java:getValue($language, 'excelmap.bids.bids.BidAction')]/@column)"/>
        	</xsl:when>        	
        	<xsl:when test="($buyerside = 'true') and
        					($bid.rfxtype = 'reverse') and
        					($discountBidding = 'false')">
        		<xsl:value-of select="number(13)"/>
        	</xsl:when>
        	<xsl:when test="($buyerside = 'true') and
        					($bid.rfxtype = 'reverse') and
        					($discountBidding = 'true')">
        		<xsl:value-of select="number(16)"/>
        	</xsl:when>        
        	<xsl:when test="($buyerside = 'true') and
        					($bid.rfxtype = 'forward')">
        		<xsl:value-of select="number(13)"/>
        	</xsl:when>           
        </xsl:choose>
    </xsl:variable>
    
    <!-- RFXMG-START -->    
    <xsl:variable name="bundled.bid.row" select="0" saxon:assignable="yes"/>
    <xsl:variable name="volume.bid.row" select="0" saxon:assignable="yes"/>
    <xsl:variable name="Bid.Types.Header.Row.Incr" select="$bidtemplate.bid.header/@row"/>
    <xsl:variable name="Bid.Types.Header.Row" select="$Bid.Types.Header.Row.Incr - 3"/>
    <xsl:variable name="Bid.Types.Header" select="book/sheet/range/row[@row=$Bid.Types.Header.Row]"/>    
    <xsl:variable name="simple.bid.column" select="0" saxon:assignable="yes"/>
    <xsl:variable name="bundled.bid.column" select="0" saxon:assignable="yes"/>
    <xsl:variable name="volume.bid.column" select="0" saxon:assignable="yes"/>    
        
    <!--<xsl:variable name="ppu.column" select="0" saxon:assignable="yes"/>
   	<xsl:variable name="otc.column" select="0" saxon:assignable="yes"/>    
   	--><xsl:variable name="process.simple.bid" select="0" saxon:assignable="yes"/>    
   	<xsl:variable name="bundled.bid.action" select="0" saxon:assignable="yes"/>    
   	<xsl:variable name="SimpleBidEndColumn" select="0" saxon:assignable="yes"/>    
   	<xsl:variable name="TableResponseComment" select="''" saxon:assignable="yes"/>    
    <!-- RFXMG-END -->

    <!-- ******************************************** -->
    <!-- createBids: create response and bid elements -->
    <!-- ******************************************** -->
    <xsl:template match="row" mode="createBids">

        <!--Defined to calculate the column position of simple, bundle & volume discount bids-->
    	<xsl:for-each select="$Bid.Types.Header/cell">    	
	    	<xsl:if test=". = java:getValue($language,'excelmap.bids.headers.section.simplebids')">
	    		<saxon:assign name="simple.bid.column" select="./@column"/>
	    	</xsl:if>
	    	<xsl:if test=". = java:getValue($language,'excelmap.bids.bundle.bundlebids')">
	    		<saxon:assign name="bundled.bid.column" select="./@column"/>
	    	</xsl:if>
	    	<xsl:if test=". = java:getValue($language,'excelmap.bids.headers.section.volumediscountbids')">
	    		<saxon:assign name="volume.bid.column" select="./@column"/>
	    	</xsl:if>
    	</xsl:for-each>

        <!--User defined bid IA are present between simple bid & bundle bid so check the column position where
            simple bid columns end. Bundle Bid area & volume discount bid area always contain fixed no. of columns.
            Simple bid area contain variable columns (depends on user defined IAs)                         
        -->
    	<xsl:choose>
    		<xsl:when test="$volume.bid.column &gt; $bundled.bid.column">
    			<xsl:choose>
    				<xsl:when test="$bundled.bid.column != 0">
    					<saxon:assign name="SimpleBidEndColumn" select="$bundled.bid.column"/>
    				</xsl:when>
    				<xsl:otherwise>
    					<saxon:assign name="SimpleBidEndColumn" select="$volume.bid.column"/>
    				</xsl:otherwise>
    			</xsl:choose>
    		</xsl:when>
    		<xsl:when test="$bundled.bid.column &gt; $volume.bid.column">
    			<xsl:choose>
    				<xsl:when test="$volume.bid.column != 0">
    					<saxon:assign name="SimpleBidEndColumn" select="$volume.bid.column"/>
    				</xsl:when>
    				<xsl:otherwise>
    					<saxon:assign name="SimpleBidEndColumn" select="$bundled.bid.column"/>
    				</xsl:otherwise>
    			</xsl:choose>
    		</xsl:when>
    	</xsl:choose>    	

        
        <xsl:element name="createBids">
            <!-- attributes for createBids element -->
			<xsl:attribute name="OrganizationCode">
                <xsl:value-of select="$bidtemplate.orgcode/cell[@column='2']"/>
            </xsl:attribute>
			<xsl:attribute name="RFxCode">
                <xsl:value-of select="$bidtemplate.rfxcode/cell[@column='2']"/>
            </xsl:attribute>

            <xsl:variable name="bid.isRFI" select="$bid.rfxtype='rfi' or $bid.rfxtype='buyer_rfi'"/>

            <!--RFI & RFP contain questions of all types including table type-->
            <xsl:if test="$bid.isRFI or $bid.rfxtype='rfp'">
                <!--Process responses to all types of questions except Table(matrix)-->
                <xsl:apply-templates
                        select="following-sibling::row[(number(@row) &gt;= $bidtemplate.response.header.row + 1)
                                and (number(@row) &lt; $bidtemplate.matrix.row)]" mode="Response"/>
                <!--Process responses to Table(matrix) type questions-->
            	<xsl:apply-templates
                        select="following-sibling::row[(number(@row) &gt;= $bidtemplate.matrix.row)
                                and (number(@row) &lt; $bidtemplate.bid.header.row)]" mode="matrixResponse"/>
            </xsl:if>
           
            <!--Process only RFP and RFQ bids.-->
            <xsl:if test="$bid.rfxtype='sealed' or $bid.rfxtype='rfp'">            	
                <xsl:apply-templates
                        select="following-sibling::row[(number(@row) &gt;= $bidtemplate.bid.header.row + 4)
                                and (number(@row) &lt;= $bidtemplate.instr.row)]" mode="Bid"/>
            </xsl:if>
            
            <!--Process only reverse and forward auction bids.-->
            <xsl:if test="not($bid.isRFI) and $bid.rfxtype!='rfp' and $bid.rfxtype!='sealed'">            	
                <xsl:apply-templates
                        select="following-sibling::row[(number(@row) &gt;= $bidtemplate.bid.header.row + 4)
                                and (number(@row) &lt;= $bidtemplate.instr.row)]" mode="Bid"/>
            </xsl:if>

            
            <!--For denali, we are only supporting volume discount bids of RFQ & RFP i.e. non-auctions
                Import of  volume discount bids for Rev/For auction is not supported.
            -->
            <xsl:if test="($bid.rfxtype='rfp' or $bid.rfxtype='sealed') and $volume.bid.row != 0">
            	<xsl:call-template name="VolumeBids">
            		<xsl:with-param name="volumebids"
                        select="following-sibling::row[(number(@row) &gt;= $volume.bid.row)
                        		and (number(@row) &lt;= $bidtemplate.instr.row)]" />
                </xsl:call-template>
            </xsl:if>

            <!--For denali, we are only supporting bundle bids of RFQ & RFP i.e. non-auctions
                Import of  bundle bids for Rev/For auction is not supported.
            -->
            <xsl:if test="($bid.rfxtype='rfp' or $bid.rfxtype='sealed') and $bundled.bid.row != 0">                	
            	<xsl:call-template name="BundleBid">
                	<xsl:with-param name="bundlebids" 
                			select="following-sibling::row[(number(@row) &gt;= $bundled.bid.row)
                        		and (number(@row) &lt;= $bidtemplate.instr.row)]"/>
               </xsl:call-template>
            </xsl:if>
        </xsl:element>
    </xsl:template>

    <!-- *************************************************** -->
    <!-- Bid(s): bid element(s) to be processed per each row -->
    <!-- *************************************************** -->
    <xsl:template match="row" mode="Response">
        <xsl:if test="./node() and cell[@column='1'] and cell[@column='3']">
            <xsl:variable name="answer" select="cell[number(@column)=$org.response.offset]"/>
            <xsl:variable name="comment" select="cell[number(@column)=$org.response.offset + 1]"/>
            <xsl:if test="(boolean($answer) and $answer != '' and $answer != 'XXXXX')
                    or (boolean($comment) and $comment != '' and $comment != 'XXXXX')">
                <xsl:element name="Response">
                    <xsl:apply-templates select="cell" mode="FixResponseAttributes"/>
                    <!--<xsl:call-template name="bidMatrix">
                        <xsl:with-param name="response" select="."/>
                    </xsl:call-template>
                    --><xsl:call-template name="logRowId"/>
                </xsl:element>
            </xsl:if>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="row" mode="matrixResponse">
        <xsl:if test="./node() and cell[@column='2'] and cell[@column='3']">
            <xsl:variable name="answer" select="cell[number(@column)=$org.response.offset]"/>
            <xsl:variable name="comment" select="cell[number(@column)=$org.response.offset + 1]"/>
            <xsl:if test="(boolean($answer) and $answer != '' and $answer != 'XXXXX')
                    or (boolean($comment) and $comment != '' and $comment != 'XXXXX')">
                <xsl:choose>
                    <xsl:when test="cell[@column='1'] = $TableResponse">
                    </xsl:when>
                    <xsl:otherwise>
	                <xsl:element name="Response">
	                    <xsl:apply-templates select="cell" mode="Matrix_FixResponseAttributes"/>
	                    <xsl:attribute name="ResponseValue">
		    				<xsl:value-of select="'Table Response'"/>
	    				</xsl:attribute>
	    				<saxon:assign name="TableResponseComment" select="''"/>
	                    <xsl:call-template name="bidMatrix">
	                        <xsl:with-param name="response" select="."/>
	                    </xsl:call-template>	                    	                    
	                    <xsl:call-template name="logRowId"/>
	                </xsl:element>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:if>
        </xsl:if>
    </xsl:template>

    <!-- all fixed attributes -->
    <xsl:template match="cell" mode="FixResponseAttributes">
        <xsl:if test="(@column='1') or (@column='3') or (number(@column) &gt; 11)">
            <xsl:if test=". != 'XXXXX'">
                <xsl:call-template name="FixAttribute">
                    <xsl:with-param name="header" select="$bidtemplate.response.header"/>
                    <xsl:with-param name="prefix" select="'excelmap.bids.'"/>
                </xsl:call-template>
            </xsl:if>
        </xsl:if>
    </xsl:template>
    
    <!-- all fixed attributes for table response -->
    <xsl:template match="cell" mode="Matrix_FixResponseAttributes">
    	<xsl:choose>
    		<xsl:when test="@column='2'">
    			<xsl:attribute name="ResponseQuestionnaire">
    				<xsl:value-of select="."/>
    			</xsl:attribute>
    		</xsl:when>
    		<xsl:when test="@column='3'">
    			<xsl:attribute name="ResponseQuestion">
    				<xsl:value-of select="."/>
    			</xsl:attribute>
    		</xsl:when>    		   		
    	</xsl:choose>
    </xsl:template>

    <xsl:template name="bidMatrix">
        <xsl:param name="response"/>

        <!--get the questionnaire name from column 2-->
        <xsl:variable name="questionnaire" select="$response/cell[@column='2']"/>

        <!--get the question name from column 3-->
        <xsl:variable name="question" select="$response/cell[@column='3']"/>


        <xsl:variable name="respondant">
            <xsl:choose>
                <xsl:when test="not($org.bid.buyer)"/>
                <xsl:otherwise>
                    <xsl:value-of select="concat($response/cell[@column='12'], ',', $response/cell[@column='13'])"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>

        <!--It stores the complete row element of matrix header-->
        <xsl:variable name="header" select="//row
                [number(@row) &gt;= $bidtemplate.matrix.row and number(@row) &lt; $bidtemplate.bid.header.row]
                [cell[@column='1']=$TableResponse][cell[@column='2']=$questionnaire][cell[@column='3']=$question]"/>

        <!--find out the rows which contain information pertaining to matrix questions-->
        <xsl:variable name="rowset" select="//row
                [number(@row) &gt; $bidtemplate.matrix.row and number(@row) &lt; $bidtemplate.bid.header.row]
                [cell[@column='2']=$questionnaire][cell[@column='3']=$question][cell[@column='4']!=$FieldLabel]
                [not($org.bid.buyer) or $respondant = concat(cell[@column='12'], ',', cell[@column='13'])]"/>        
        

        <!--if it is buyer user then create xml attributes for storing buyer submission fields information-->
    	<xsl:if test="($buyerside = 'true')">
	    	<xsl:for-each select="$rowset">
	    		<xsl:attribute name="ResponderOrganizationCode">
	   				<xsl:value-of select="cell[@column=12]"/>
	   			</xsl:attribute>
	   			<xsl:attribute name="ResponderLoginName">
	    				<xsl:value-of select="cell[@column=13]"/>
	   			</xsl:attribute>
	   			<xsl:attribute name="ResponseSubmitterLoginName">
	    				<xsl:value-of select="cell[@column=14]"/>
	   			</xsl:attribute>
	    	</xsl:for-each>
	    </xsl:if>
	    
	    <!-- For loop for retrieving the comment and creating the  attribute (ResponseComment)-->
	    <xsl:for-each select="$header/cell[number(@column) &gt;= $org.matrix.offset]">
	    	<xsl:variable name="recordColumn" select="@column"/>
	    	<xsl:if test=". = java:getValue($language, 'excelmap.bids.response.ResponseComments')">
	    		<xsl:for-each select="$rowset">
	    			<xsl:attribute name="ResponseComments">
		    			<xsl:value-of select="cell[@column=$recordColumn]"/>
    				</xsl:attribute>
	    		</xsl:for-each>
	    	</xsl:if>
	    </xsl:for-each>
    		
        <xsl:element name="TableValue">        	
            <!--Iterate through the columns having col. no. greater than $org.matrix.offset-->
            <xsl:for-each select="$header/cell[number(@column) &gt;= $org.matrix.offset]">
                <xsl:variable name="recordColumn" select="@column"/>                
               	<!--if column do not contain value "Response Comments" then process it-->
               	<xsl:if test="not(. = java:getValue($language, 'excelmap.bids.response.ResponseComments'))">
               		<xsl:element name="Record">
	                    <xsl:attribute name="name">
	                        <xsl:value-of select="."/>
	                    </xsl:attribute>
	                    <xsl:for-each select="$rowset">
	                        <xsl:variable name="cell" select="cell[@column=$recordColumn]"/>
	                        <xsl:if test="$cell != 'XXXXX'">
	                            <xsl:element name="Field">
	                                <xsl:attribute name="name">
	                                    <xsl:value-of select="cell[@column='4']"/>
	                                </xsl:attribute>
	                                <xsl:attribute name="value">
	                                    <xsl:value-of select="$cell"/>
	                                </xsl:attribute>
	                                <xsl:call-template name="logRowId"/><!-- PR#60525 -->
	                            </xsl:element>
	                        </xsl:if>
	                    </xsl:for-each>
	                    <xsl:call-template name="logRowId"/><!-- PR#60525 -->
	                </xsl:element>
               	</xsl:if>                	            
            </xsl:for-each>
            <xsl:call-template name="logRowId"/><!-- PR#60525 -->
        </xsl:element>
    </xsl:template>

    <!-- *************************************************** -->
    <!-- Bid(s): bid element(s) to be processed per each row -->
    <!-- *************************************************** -->
    <xsl:template match="row" mode="Bid">    
    	<saxon:assign name="process.simple.bid" select="0"/>    	
    	<xsl:choose>
	        <xsl:when test="(./node()) and 
	        				$bundled.bid.column != 0 and
	        				$volume.bid.column !=0 and
	        				(empty(./cell[@column=$bundled.bid.column])) and
	        				(empty(./cell[@column=$bundled.bid.column + 1])) and 
	        				(empty(./cell[@column=$bundled.bid.column + 2])) and
	        				(empty(./cell[@column=$volume.bid.column])) and
	        				(empty(./cell[@column=$volume.bid.column + 1])) and 
	        				(empty(./cell[@column=$volume.bid.column + 2]))">
	            <saxon:assign name="process.simple.bid" select="1"/>
	        </xsl:when>
	        <xsl:when test="(./node()) and
	        				$bundled.bid.column = 0 and
	        				$volume.bid.column = 0 ">
	        	<saxon:assign name="process.simple.bid" select="1"/>
	        </xsl:when>
	        <xsl:when test="(./node()) and
	        				$bundled.bid.column != 0 and
	        				$volume.bid.column = 0 and
	        				(empty(./cell[@column=$bundled.bid.column])) and
	        				(empty(./cell[@column=$bundled.bid.column + 1])) and 
	        				(empty(./cell[@column=$bundled.bid.column + 2]))">
	        	<saxon:assign name="process.simple.bid" select="1"/>
	        </xsl:when>
	        <xsl:when test="(./node()) and
	        				$bundled.bid.column = 0 and
	        				$volume.bid.column != 0 and
	        				(empty(./cell[@column=$volume.bid.column])) and
	        				(empty(./cell[@column=$volume.bid.column + 1])) and 
	        				(empty(./cell[@column=$volume.bid.column + 2]))">
	        	<saxon:assign name="process.simple.bid" select="1"/>
	        </xsl:when>
	        <xsl:when test="(./node()) and 
	        				$bundled.bid.column != 0 and
	        				$volume.bid.column != 0 and
	        				((empty(./cell[@column=$bundled.bid.column])) and
	        				(empty(./cell[@column=$bundled.bid.column + 1])) and
	        				(empty(./cell[@column=$bundled.bid.column + 2]))) or
	        				(not(empty(./cell[@column=$volume.bid.column])) or
	        				 not(empty(./cell[@column=$volume.bid.column] + 1)) or
	        				 not(empty(./cell[@column=$volume.bid.column] + 2)))">
	        	<xsl:if test="$volume.bid.row = 0">
	        		<saxon:assign name="volume.bid.row" select="./@row"/>
	        	</xsl:if>
	        </xsl:when>
	        <xsl:when test="(./node()) and 
	        				$bundled.bid.column != 0 and
	        				$volume.bid.column != 0 and
	        				((empty(./cell[@column=$volume.bid.column])) and
	        				(empty(./cell[@column=$volume.bid.column + 1])) and
	        				(empty(./cell[@column=$volume.bid.column + 2]))) and
	        				(not(empty(./cell[@column=$bundled.bid.column])) or
	        				 not(empty(./cell[@column=$bundled.bid.column + 1])) or
	        				 not(empty(./cell[@column=$bundled.bid.column] + 2)))">
	        	<xsl:if test="$bundled.bid.row = 0">
	        		<saxon:assign name="bundled.bid.row" select="./@row"/>
	        	</xsl:if>
	        </xsl:when>
	        <xsl:when test="(./node()) and 
	        				$bundled.bid.column != 0 and
	        				$volume.bid.column = 0 and	        				
	        				(not(empty(./cell[@column=$bundled.bid.column])) or
	        				 not(empty(./cell[@column=$bundled.bid.column + 1])) or
	        				 not(empty(./cell[@column=$bundled.bid.column] + 2)))">
	        	<xsl:if test="$bundled.bid.row = 0">
	        		<saxon:assign name="bundled.bid.row" select="./@row"/>
	        	</xsl:if>
	        </xsl:when>
	        <xsl:when test="(./node()) and 
	        				$bundled.bid.column = 0 and
	        				$volume.bid.column != 0 and	        				
	        				(not(empty(./cell[@column=$volume.bid.column])) or
	        				 not(empty(./cell[@column=$volume.bid.column] + 1)) or
	        				 not(empty(./cell[@column=$volume.bid.column] + 2)))">
	        	<xsl:if test="$volume.bid.row = 0">
	        		<saxon:assign name="volume.bid.row" select="./@row"/>
	        	</xsl:if>
	        </xsl:when>
	    </xsl:choose>

	    <xsl:if test="$process.simple.bid = 1">	    	
            <!-- PR#59749:commented if statement
	    	<xsl:variable name="row.full">
                <xsl:for-each select="cell[number(@column) &gt; $org.bid.offset]">                	
                    <xsl:if test="(. != '') and (. != 'XXXXX')">                    	
                        <xsl:value-of select="."/>
                    </xsl:if>
                </xsl:for-each>
            </xsl:variable>            
            <xsl:if test="string-length($row.full) &gt; 0">
            -->
            <!-- Commented for PRs 63108, 62272 as null bid import was allowed in 5.2 -->
			<!-- PR 65918 Action type check skiped for RA and FA -->
            <xsl:if test="$bid.rfxtype = 'reverse' or $bid.rfxtype = 'forward' or not(empty(./cell[@column=$ActionColumnPosition])) and ./cell[@column=$ActionColumnPosition ] != '' "> <!--PR 65267-->
                <xsl:element name="Bid">
                    <xsl:attribute name="BidType">
                        <xsl:value-of select="java:getValue($language, 'integration.BidType.SimpleBid')"/>
                    </xsl:attribute>
                    <xsl:if test="$buyerside = 'true'">
                    	<xsl:variable name="buyerFieldColumn">
                    		<xsl:choose>
                    			<xsl:when test="($bid.rfxtype = 'reverse') or 
		    									($bid.rfxtype = 'forward')">
		    						<xsl:value-of select="1"/>
                    			</xsl:when>
                    			<xsl:otherwise>
                    				<xsl:value-of select="0"/>
                    			</xsl:otherwise>
                    		</xsl:choose>
                    	</xsl:variable>
	                    <xsl:attribute name="BidderOrganizationCode">
				 			<xsl:value-of select="./cell[@column=($org.bid.offset - ($buyerFieldColumn + 3))]"/>
				 		</xsl:attribute>
				  		<xsl:attribute name="BidderLoginName">
				 			<xsl:value-of select="./cell[@column=($org.bid.offset - ($buyerFieldColumn + 2))]"/>
					 	</xsl:attribute>
					 	<xsl:if test="not(empty(./cell[@column=($org.bid.offset - ($buyerFieldColumn + 1))]))">
							<xsl:attribute name="BidSubmitterLoginName">
					 			<xsl:value-of select="./cell[@column=($org.bid.offset - ($buyerFieldColumn + 1))]"/>
					 		</xsl:attribute>
				 		</xsl:if> 
				 		<xsl:if test="($bid.rfxtype = 'reverse') or 
     								  ($bid.rfxtype = 'forward')">
				 			<xsl:attribute name="BidIsPreliminary">
					 			<xsl:value-of select="./cell[@column=($org.bid.offset - 1)]"/>
					 		</xsl:attribute>
				 		</xsl:if>				 		
				 	</xsl:if>
				 	<xsl:attribute name="BidLineItemCode">
						<xsl:value-of select="./cell[@column=2]"/>
					</xsl:attribute> 
				 	<xsl:attribute name="BidCurrencyCode">
			 			<xsl:value-of select="./cell[@column=($org.bid.offset + 1)]"/>
			 		</xsl:attribute>
			 		<xsl:attribute name="BidAction">
			 			<xsl:value-of select="./cell[@column=($org.bid.offset)]"/>
			 		</xsl:attribute>
			 		<xsl:apply-templates select="cell[number(@column) &gt;= ($org.bid.offset + 2)]" mode="ExtendAttributes"/>
                     <xsl:call-template name="logRowId"/>
                </xsl:element>
	        </xsl:if>
	    </xsl:if>
    </xsl:template>
    
    

    <!-- first org.offset columns are fixed attributes, all others are extended attributes -->
    <xsl:template match="cell" mode="FixBidAttributes">     	
    	<xsl:choose>    		
    		<xsl:when test="($buyerside = 'true') and ((@column='2') or (@column=($org.bid.offset)) or (@column=($org.bid.offset)))">					    		
    			<xsl:call-template name="FixAttribute">
    	            <xsl:with-param name="header" select="$bidtemplate.bid.header"/>
        	        <xsl:with-param name="prefix" select="'excelmap.bids.'"/>
	            </xsl:call-template>
    		</xsl:when>
    		<xsl:when test="($buyerside = 'false') and ((@column='2') or (@column= ($org.bid.offset)) or (@column=($org.bid.offset + 1)))">
    			<xsl:call-template name="FixAttribute">
    	            <xsl:with-param name="header" select="$bidtemplate.bid.header"/>
        	        <xsl:with-param name="prefix" select="'excelmap.bids.'"/>
	            </xsl:call-template>
    		</xsl:when>
    	</xsl:choose>        
    </xsl:template>

    <!-- columns beyond the org.offset, make ExtendedAttribute elements -->
    <!-- FILTER OUT ANY VALUES THAT ARE OF 'XXXXX' -->
    <xsl:template match="cell" mode="ExtendAttributes">
        <xsl:if test="(. != 'XXXXX')">
        	<xsl:if test="$bundled.bid.column = 0 and $volume.bid.column = 0">
	            <xsl:call-template name="ExtendedAttribute">
    	            <xsl:with-param name="header" select="$bidtemplate.bid.header"/>
        	    </xsl:call-template>
        	</xsl:if>
        	<xsl:if test="(. != 'XXXXX') and 
        					$bundled.bid.column != 0 and 
        					$volume.bid.column != 0  and
        					(number(./@column) &lt; number($bundled.bid.column)) and (number(./@column) &lt; number($volume.bid.column))">
        		<xsl:call-template name="ExtendedAttribute">
    	            <xsl:with-param name="header" select="$bidtemplate.bid.header"/>
        	    </xsl:call-template>
        	</xsl:if>
        	<xsl:if test="(. != 'XXXXX') and
        					$bundled.bid.column = 0 and 
        					$volume.bid.column != 0 and
        					not(./@column &gt;= $volume.bid.column)">
        		<xsl:call-template name="ExtendedAttribute">
    	            <xsl:with-param name="header" select="$bidtemplate.bid.header"/>
        	    </xsl:call-template>
        	</xsl:if>
        	<xsl:if test="(. != 'XXXXX') and
        					$bundled.bid.column != 0 and 
        					$volume.bid.column = 0 and
        					not(./@column &gt;= $bundled.bid.column)">
        		<xsl:call-template name="ExtendedAttribute">
    	            <xsl:with-param name="header" select="$bidtemplate.bid.header"/>
        	    </xsl:call-template>
        	</xsl:if>
        </xsl:if>
    </xsl:template>
    
    <!-- RFXMG-START -->
    <!-- *************************************************** -->
    <!-- Volume Bids: bid elements to be processed per each row -->
    <!-- *************************************************** -->
    <xsl:template name="VolumeBids">
    	<xsl:param name="volumebids"/>    	
    	<!--<xsl:for-each select="$bidtemplate.bid.header/cell">
    		<xsl:if test=". = java:getValue($language, 'excelmap.bids.bundled.priceperunit')">
    			<saxon:assign name="ppu.column" select="./@column"/>		    	
    		</xsl:if>
    		<xsl:if test=". = java:getValue($language, 'excelmap.bids.bundled.onetimecharge')">
    			<saxon:assign name="otc.column" select="./@column"/>		    	
    		</xsl:if>
	    </xsl:for-each>
    	--><xsl:variable name="itemuniqueids" select="java:createMap('itemuniqueids')"/>
    	<xsl:variable name="AttributeFlag" select="java:createMap('AttributeFlag')"/>  
    	
    	<xsl:choose>
    		<xsl:when test="$buyerside = 'true'">
				<xsl:for-each select="$volumebids">    		
		   			<!-- xsl:if test="./cell[@column=$column] != ' '"-->		   			
		   			<xsl:if test="empty(./cell[@column=$bundled.bid.column]) and
   	    						  empty(./cell[@column=$bundled.bid.column + 1]) and
   	    						  empty(./cell[@column=$bundled.bid.column + 2]) and
    						  	  (not(empty(./cell[@column=$volume.bid.column])) or 
    						      not(empty(./cell[@column=$volume.bid.column + 1])) or 
    						      not(empty(./cell[@column=$volume.bid.column + 2])))">
    					
   						<xsl:if test="not(java:containsValue($itemuniqueids, concat(./cell[@column='2'], ./cell[@column=($org.bid.offset - 3)]), ./@row))">
   							<xsl:value-of select="java:addValue($itemuniqueids, concat(./cell[@column='2'], ./cell[@column=($org.bid.offset - 3)]), ./@row)" />
			    		</xsl:if>
			    	</xsl:if>
   					<!--  /xsl:if-->	    		
    			</xsl:for-each>
    		</xsl:when>
    		<xsl:otherwise>
				<xsl:for-each select="$volumebids">    		
		   			<!-- xsl:if test="./cell[@column=$column] != ' '"-->
		   			<xsl:if test="empty(./cell[@column=$bundled.bid.column]) and
   	    						  empty(./cell[@column=$bundled.bid.column + 1]) and
   	    						  empty(./cell[@column=$bundled.bid.column + 2]) and
    						  	  not(empty(./cell[@column=$volume.bid.column])) or 
    						      not(empty(./cell[@column=$volume.bid.column + 1])) or 
    						      not(empty(./cell[@column=$volume.bid.column + 2]))">
   						<xsl:if test="not(java:containsValue($itemuniqueids, ./cell[@column='2'], ./@row))">
   							<xsl:value-of select="java:addValue($itemuniqueids, ./cell[@column='2'], ./@row)" />
		    			</xsl:if>
		    		</xsl:if>
   					<!--  /xsl:if-->	    		
    			</xsl:for-each>
    		</xsl:otherwise>
    	</xsl:choose>    	
    	<xsl:variable name="itemiditerator" select="java:getKeyIterator($itemuniqueids)"/>
    	<saxon:while test="java:hasNext($itemiditerator)">
    		<xsl:variable name="itemid" select="java:getNextKey($itemiditerator)"/> 
    		<xsl:value-of select="java:addAttributeFlag($AttributeFlag, '0')"/>
    		<xsl:element name="Bid">
	    		<xsl:attribute name="BidType">
   					<xsl:value-of select="java:getValue($language, 'integration.BidType.VolumeBid')"/>
	    		</xsl:attribute>
	    		<xsl:choose>
	    			<xsl:when test="$buyerside = 'true'">
	    				<xsl:for-each select="$volumebids">	
							<xsl:variable name="rowNum" select="./@row"/>		
							<xsl:if test="empty(./cell[@column=$bundled.bid.column]) and
   	    						   		  empty(./cell[@column=$bundled.bid.column + 1]) and
		 	    						  empty(./cell[@column=$bundled.bid.column + 2]) and
	      						  	      not(empty(./cell[@column=$volume.bid.column])) or 
    						              not(empty(./cell[@column=$volume.bid.column + 1])) or 
    						              not(empty(./cell[@column=$volume.bid.column + 2]))">							
							<xsl:if test="((concat(./cell[@column='2'], ./cell[@column=($org.bid.offset - 3)])) = $itemid)">
								<xsl:variable name="attributeFlag" select="java:getAttributeFlag($AttributeFlag)"/>
								<xsl:if test="$attributeFlag = 0">
				  					<xsl:attribute name="BidderOrganizationCode">
				 						<xsl:value-of select="./cell[@column=($org.bid.offset - 3)]"/>
				 					</xsl:attribute>
				  					<xsl:attribute name="BidderLoginName">
				 						<xsl:value-of select="./cell[@column=($org.bid.offset - 2)]"/>
					 				</xsl:attribute>
					 				<xsl:if test="not(empty(./cell[@column=($org.bid.offset - 1)]))">
						 				<xsl:attribute name="BidSubmitterLoginName">
					 						<xsl:value-of select="./cell[@column=($org.bid.offset - 1)]"/>
					 					</xsl:attribute>
				 					</xsl:if>
									<xsl:attribute name="BidLineItemCode">
			   							<xsl:value-of select="./cell[@column=1]"/>
			  						</xsl:attribute>   						
									<xsl:attribute name="VolumeDiscount">
			   							<xsl:value-of select="./cell[@column=$volume.bid.column]"/>
			   						</xsl:attribute>
			   						<xsl:attribute name="BidCurrencyCode">
				   							<xsl:value-of select="./cell[@column=($org.bid.offset + 1)]"/>
			   						</xsl:attribute>
			   						<xsl:value-of select="java:addAttributeFlag($AttributeFlag, '1')"/>
			   					</xsl:if>
								<xsl:element name="Bid">
									<xsl:attribute name="BidderOrganizationCode">
		   								<xsl:value-of select="./cell[@column=($org.bid.offset - 3)]"/>
		   							</xsl:attribute>
		    						<xsl:attribute name="BidderLoginName">
		   								<xsl:value-of select="./cell[@column=($org.bid.offset - 2)]"/>
		   							</xsl:attribute>
		   							<xsl:if test="not(empty(./cell[@column=($org.bid.offset - 1)]))">
			   							<xsl:attribute name="BidSubmitterLoginName">
			   								<xsl:value-of select="./cell[@column=($org.bid.offset - 1)]"/>
			   							</xsl:attribute>		    						
			   						</xsl:if>
						    		<xsl:attribute name="BidLineItemCode">
			   							<xsl:value-of select="./cell[@column=1]"/>
			   						</xsl:attribute>   						
									<xsl:attribute name="VolumeDiscount">
			   							<xsl:value-of select="./cell[@column=$volume.bid.column]"/>
			   						</xsl:attribute>
			   						<xsl:attribute name="BidMinimum">
			   							<xsl:value-of select="./cell[@column=$volume.bid.column + 1]"/>
			   						</xsl:attribute>
			   						<xsl:attribute name="BidMaximum">
			   							<xsl:value-of select="./cell[@column=$volume.bid.column + 2]"/>
			   						</xsl:attribute>
			   						<xsl:attribute name="BidCurrencyCode">
			   							<xsl:value-of select="./cell[@column=($org.bid.offset + 1)]"/>
			   						</xsl:attribute>
			   						<!--<xsl:attribute name="BidPricePerUnit">
			   							<xsl:value-of select="./cell[@column=$ppu.column]"/>
			   						</xsl:attribute>
			   						<xsl:attribute name="BidOneTimeCharge">
			   							<xsl:value-of select="./cell[@column=$otc.column]"/>
			   						</xsl:attribute>
			   						--><xsl:attribute name="BidType">
			   							<xsl:value-of select="java:getValue($language, 'integration.BidType.SimpleBid')"/>
			   						</xsl:attribute>
			   						<xsl:apply-templates select="./cell[(number(@column) &gt;= ($org.bid.offset + 2)) and 
			   													  (number(@column) &lt; $SimpleBidEndColumn)]" mode="VolumeBidXtendedAttribute"/>
			   						<xsl:call-template name="LogRows">
										<xsl:with-param name="rowNum" select="$rowNum"/>
									</xsl:call-template>
						    	</xsl:element>
						    </xsl:if>
						    </xsl:if>
						</xsl:for-each>
	    			</xsl:when>
	    			<xsl:otherwise>
	    				<xsl:for-each select="$volumebids">	
							<xsl:variable name="rowNum" select="./@row"/>	
							<xsl:if test="empty(./cell[@column=$bundled.bid.column]) and
   	    						          empty(./cell[@column=$bundled.bid.column + 1]) and
   	    						          empty(./cell[@column=$bundled.bid.column + 2]) and
    						  	          not(empty(./cell[@column=$volume.bid.column])) or 
    						              not(empty(./cell[@column=$volume.bid.column + 1])) or 
    						              not(empty(./cell[@column=$volume.bid.column + 2]))">								
							<xsl:if test="(./cell[@column='2'] = $itemid)">								
							<xsl:variable name="attributeFlag" select="java:getAttributeFlag($AttributeFlag)"/>
								<xsl:if test="$attributeFlag = 0">
									<xsl:attribute name="BidLineItemCode">
			   							<xsl:value-of select="./cell[@column=1]"/>
			  						</xsl:attribute>   						
									<xsl:attribute name="VolumeDiscount">
			   							<xsl:value-of select="./cell[@column=$volume.bid.column]"/>
			   						</xsl:attribute>
			   						<xsl:attribute name="BidCurrencyCode">
				   							<xsl:value-of select="./cell[@column=($org.bid.offset + 1)]"/>
			   						</xsl:attribute>
				   					<xsl:value-of select="java:addAttributeFlag($AttributeFlag, '1')"/>
			   					</xsl:if>
								<xsl:element name="Bid">			   						
						    		<xsl:attribute name="BidLineItemCode">
			   							<xsl:value-of select="./cell[@column=1]"/>
			   						</xsl:attribute>   						
									<xsl:attribute name="VolumeDiscount">
			   							<xsl:value-of select="./cell[@column=$volume.bid.column]"/>
			   						</xsl:attribute>
			   						<xsl:attribute name="BidMinimum">
			   							<xsl:value-of select="./cell[@column=$volume.bid.column + 1]"/>
			   						</xsl:attribute>
			   						<xsl:attribute name="BidMaximum">
			   							<xsl:value-of select="./cell[@column=$volume.bid.column + 2]"/>
			   						</xsl:attribute>
			   						<xsl:attribute name="BidCurrencyCode">
			   							<xsl:value-of select="./cell[@column=($org.bid.offset + 1)]"/>
			   						</xsl:attribute>
			   						<!--<xsl:attribute name="BidPricePerUnit">
			   							<xsl:value-of select="./cell[@column=$ppu.column]"/>
			   						</xsl:attribute>
			   						<xsl:attribute name="BidOneTimeCharge">
			   							<xsl:value-of select="./cell[@column=$otc.column]"/>
			   						</xsl:attribute>
			   						--><xsl:attribute name="BidType">
			   							<xsl:value-of select="java:getValue($language, 'integration.BidType.SimpleBid')"/>
			   						</xsl:attribute>
			   						<xsl:apply-templates select="./cell[(number(@column) &gt;= ($org.bid.offset + 2)) and 
			   													 (number(@column) &lt; $SimpleBidEndColumn)]" mode="VolumeBidXtendedAttribute"/>
			   						<xsl:call-template name="LogRows">
										<xsl:with-param name="rowNum" select="$rowNum"/>
									</xsl:call-template>
						    	</xsl:element>
						    </xsl:if>
						    </xsl:if>
						</xsl:for-each>	
	    			</xsl:otherwise>
	    		</xsl:choose>  
			</xsl:element> 		    			
    	</saxon:while>
    </xsl:template>
    
    <!-- *************************************************** -->
    <!-- Bundle Bids: bid elements to be processed per each row -->
    <!-- *************************************************** -->
    <xsl:template name="BundleBid">
    	<xsl:param name="bundlebids"/>      	
    	<!--<xsl:for-each select="$bidtemplate.bid.header/cell">
    		<xsl:if test=". = java:getValue($language, 'excelmap.bids.bundled.priceperunit')">
    			<saxon:assign name="ppu.column" select="./@column"/>		    	
    		</xsl:if>
    		<xsl:if test=". = java:getValue($language, 'excelmap.bids.bundled.onetimecharge')">
    			<saxon:assign name="otc.column" select="./@column"/>		    	
    		</xsl:if>
	    </xsl:for-each>
    	--><xsl:variable name="bundlebidnos" select="java:createMap('bundlebidnos')"/>   
	   	<xsl:variable name="AttributeFlag" select="java:createMap('AttributeFlag')"/> 
    	  	
    	<xsl:choose>
    		<xsl:when test="$buyerside = 'true'">
			
    			<xsl:for-each select="$bundlebids">
		    		<!-- xsl:if test="./cell[@column=$bundleNo] != 'XXXXX'"-->		    			
		    			<xsl:if test="not(empty(./cell[@column=$bundled.bid.column])) or 
		    						  not(empty(./cell[@column=$bundled.bid.column + 1])) or 
		    						  not(empty(./cell[@column=$bundled.bid.column + 2]))">											  
			    			<xsl:if test="not(java:containsValue($bundlebidnos, concat(./cell[@column=$bundled.bid.column], ./cell[@column=($org.bid.offset - 3)]), ./@row))">
				    			<xsl:value-of select="java:addValue($bundlebidnos, concat(./cell[@column=$bundled.bid.column], ./cell[@column=($org.bid.offset - 3)]), ./@row)" />
				    		</xsl:if>
				    	</xsl:if>
		    		<!-- /xsl:if-->    		
    			</xsl:for-each>
    		</xsl:when>
    		<xsl:otherwise>
    			<xsl:for-each select="$bundlebids">
			   		<!-- xsl:if test="./cell[@column=$bundleNo] != 'XXXXX'"-->
			   			<xsl:if test="not(empty(./cell[@column=$bundled.bid.column])) or 
		    						  not(empty(./cell[@column=$bundled.bid.column + 1])) or 
		    						  not(empty(./cell[@column=$bundled.bid.column + 2]))">
	    					<xsl:if test="not(java:containsValue($bundlebidnos, ./cell[@column=$bundled.bid.column], ./@row))">
		    					<xsl:value-of select="java:addValue($bundlebidnos, ./cell[@column=$bundled.bid.column], ./@row)" />
				    		</xsl:if>
				    	</xsl:if>
    				<!-- /xsl:if-->    		
		    	</xsl:for-each>
    		</xsl:otherwise>
    	</xsl:choose>
    	    	
    	<xsl:variable name="bidnoiterator" select="java:getKeyIterator($bundlebidnos)"/>
    	<saxon:while test="java:hasNext($bidnoiterator)">
    		<xsl:variable name="bidno" select="java:getNextKey($bidnoiterator)"/> 
    		<xsl:value-of select="java:addAttributeFlag($AttributeFlag, '0')"/>   		    			
    		<xsl:element name="Bid">
	    		<xsl:attribute name="BidType">
   					<xsl:value-of select="java:getValue($language, 'integration.BidType.BundleBid')"/>
	    		</xsl:attribute> 
	    		<xsl:choose>
	    			<xsl:when test="$buyerside = 'true'">
	    				<xsl:for-each select="$bundlebids">   
   							<xsl:variable name="rowNum" select="./@row"/>
   							<xsl:if test="not(empty(./cell[@column=$bundled.bid.column])) or 
		    						      not(empty(./cell[@column=$bundled.bid.column + 1])) or 
		    						      not(empty(./cell[@column=$bundled.bid.column + 2]))">				
				   				<xsl:if test="((concat(./cell[@column=$bundled.bid.column], ./cell[@column=($org.bid.offset - 3)])) = $bidno) or (($bidno = 'XXX') and (empty(./cell[@column=$bundled.bid.column])))">  
				   				<xsl:variable name="attributeFlag" select="java:getAttributeFlag($AttributeFlag)"/>
								<xsl:if test="$attributeFlag = 0">
				  					<xsl:attribute name="BidderOrganizationCode">
				 						<xsl:value-of select="./cell[@column=($org.bid.offset - 3)]"/>
				 					</xsl:attribute>
				  					<xsl:attribute name="BidderLoginName">
				 						<xsl:value-of select="./cell[@column=($org.bid.offset - 2)]"/>
					 				</xsl:attribute>
					 				<xsl:if test="not(empty(./cell[@column=($org.bid.offset - 1)]))">
					 					<xsl:attribute name="BidSubmitterLoginName">
					 						<xsl:value-of select="./cell[@column=($org.bid.offset - 1)]"/>
					 					</xsl:attribute>
					 				</xsl:if>
										
									<xsl:choose>
										<xsl:when test="((($bidno = 'XXX') and (empty(./cell[@column=$bundled.bid.column]))) or (empty(./cell[@column=$bundled.bid.column])))">
											<xsl:attribute name="BundleName">
						   						<xsl:value-of select="''"/>
								    		</xsl:attribute>
										</xsl:when>
										<xsl:otherwise>
											<xsl:attribute name="BundleName">
					   							<xsl:value-of select="./cell[@column = $bundled.bid.column]"/>
								    		</xsl:attribute>
										</xsl:otherwise>
									</xsl:choose>
									<xsl:value-of select="java:addAttributeFlag($AttributeFlag, '1')"/>
			   					</xsl:if>
			   					<xsl:attribute name="BidAction">
			                        <xsl:value-of select="./cell[@column=$org.bid.offset]"/>
            				    </xsl:attribute>
									  		 			
				   					<xsl:element name="Bid">
			    						<xsl:attribute name="BidderOrganizationCode">
			   								<xsl:value-of select="./cell[@column=($org.bid.offset - 3)]"/>
			   							</xsl:attribute>
			    						<xsl:attribute name="BidderLoginName">
			   								<xsl:value-of select="./cell[@column=($org.bid.offset - 2)]"/>
			   							</xsl:attribute>
			   							<xsl:if test="not(empty(./cell[@column=($org.bid.offset - 1)]))">
				   							<xsl:attribute name="BidSubmitterLoginName">
				   								<xsl:value-of select="./cell[@column=($org.bid.offset - 1)]"/>
				   							</xsl:attribute>
				   						</xsl:if>
							    		
							    		<xsl:choose>
											<xsl:when test="(($bidno = 'XXX') and (empty(./cell[@column=$bundled.bid.column])))">
												<xsl:attribute name="BundleName">
							   						<xsl:value-of select="''"/>
									    		</xsl:attribute>
											</xsl:when>
											<xsl:otherwise>
												<xsl:attribute name="BundleName">
						   							<xsl:value-of select="./cell[@column = $bundled.bid.column]"/>
									    		</xsl:attribute>
											</xsl:otherwise>
										</xsl:choose>						
				   						<xsl:attribute name="BidLineItemCode">
				   							<xsl:value-of select="./cell[@column=1]"/>
				   						</xsl:attribute>
				   						<xsl:attribute name="BidAction">
					                        <xsl:value-of select="./cell[@column=($org.bid.offset)]"/>
    	            				    </xsl:attribute>
				   						<xsl:attribute name="BidCurrencyCode">
				   							<xsl:value-of select="./cell[@column=($org.bid.offset + 1)]"/>
				   						</xsl:attribute>
				   						<!--<xsl:attribute name="BidPricePerUnit">
				   							<xsl:value-of select="./cell[@column=$ppu.column]"/>
				   						</xsl:attribute>
				   						<xsl:attribute name="BidOneTimeCharge">
				   							<xsl:value-of select="./cell[@column=$otc.column]"/>
				   						</xsl:attribute>
				   						--><xsl:attribute name="PPUPercentDiscount">
				   							<xsl:value-of select="./cell[@column=$bundled.bid.column + 1]"/>
				   						</xsl:attribute>
				   						<xsl:attribute name="OTCPercentDiscount">
				   							<xsl:value-of select="./cell[@column=$bundled.bid.column + 2]"/>
				   						</xsl:attribute>
				   						<xsl:attribute name="BidType">
				   							<xsl:value-of select="java:getValue($language, 'integration.BidType.SimpleBid')"/>
				   						</xsl:attribute>
				   						<xsl:attribute name="BidPPUDiscountType">
				   							<xsl:value-of select="java:getValue($language, 'excelmap.bids.bundle.ppu.discounttype.percent')"/>
				   						</xsl:attribute>
				   						<xsl:attribute name="BidOTCDiscountType">
				   							<xsl:value-of select="java:getValue($language, 'excelmap.bids.bundle.otc.discounttype.percent')"/>
				   						</xsl:attribute>
				   						<xsl:apply-templates select="./cell[(number(@column) &gt;= ($org.bid.offset + 2)) and
				   						                             (number(@column) &lt; $SimpleBidEndColumn)]" mode="ExtendAttributes"/>
				   						<xsl:call-template name="LogRows">
												<xsl:with-param name="rowNum" select="$rowNum"/>
										</xsl:call-template>
				   					</xsl:element>
				   				</xsl:if>
				   			</xsl:if>
		   				 </xsl:for-each>
	    			</xsl:when>
	    			<xsl:otherwise>
	    				<xsl:for-each select="$bundlebids">	    					
   							<xsl:variable name="rowNum" select="./@row"/>				   							
   							<xsl:if test="not(empty(./cell[@column=$bundled.bid.column])) or 
		    						      not(empty(./cell[@column=$bundled.bid.column + 1])) or 
		    						      not(empty(./cell[@column=$bundled.bid.column + 2]))">
				   				<xsl:if test="(./cell[@column=$bundled.bid.column] = $bidno)">  			   					
				   				<xsl:variable name="attributeFlag" select="java:getAttributeFlag($AttributeFlag)"/>
								<xsl:if test="$attributeFlag = 0">
									<xsl:choose>
										<xsl:when test="(($bidno = 'XXX') and (empty(./cell[@column=$bundled.bid.column])))">
											<xsl:attribute name="BundleName">
						   						<xsl:value-of select="''"/>
								    		</xsl:attribute>
										</xsl:when>
										<xsl:otherwise>
											<xsl:attribute name="BundleName">
					   							<xsl:value-of select="./cell[@column = $bundled.bid.column]"/>
								    		</xsl:attribute>
										</xsl:otherwise>
									</xsl:choose>									
									<!-- PR 65273 -->
			   					<xsl:attribute name="BidAction">
			                        <xsl:value-of select="./cell[@column=($org.bid.offset)]"/>
	           				    </xsl:attribute>
									<xsl:value-of select="java:addAttributeFlag($AttributeFlag, '1')"/>
			   					</xsl:if>
				   					<xsl:element name="Bid">			   						   
							    		<xsl:choose>
											<xsl:when test="(($bidno = 'XXX') and (empty(./cell[@column=$bundled.bid.column])))">
												<xsl:attribute name="BundleName">
							   						<xsl:value-of select="''"/>
									    		</xsl:attribute>
											</xsl:when>
											<xsl:otherwise>
												<xsl:attribute name="BundleName">
						   							<xsl:value-of select="./cell[@column = $bundled.bid.column]"/>
									    		</xsl:attribute>
											</xsl:otherwise>
										</xsl:choose>
																
				   						<xsl:attribute name="BidLineItemCode">
				   							<xsl:value-of select="./cell[@column='1']"/>
				   						</xsl:attribute>
				   						<xsl:attribute name="BidAction">
					                        <xsl:value-of select="./cell[@column=($org.bid.offset)]"/>
    	            				    </xsl:attribute>
				   						<xsl:attribute name="BidCurrencyCode">
				   							<xsl:value-of select="./cell[@column=($org.bid.offset + 1)]"/>
				   						</xsl:attribute>
				   						<!--<xsl:attribute name="BidPricePerUnit">
				   							<xsl:value-of select="./cell[@column=$ppu.column]"/>
				   						</xsl:attribute>
				   						<xsl:attribute name="BidOneTimeCharge">
				   							<xsl:value-of select="./cell[@column=$otc.column]"/>
				   						</xsl:attribute>
				   						--><xsl:attribute name="PPUPercentDiscount">
				   							<xsl:value-of select="./cell[@column=$bundled.bid.column + 1]"/>
				   						</xsl:attribute>
				   						<xsl:attribute name="OTCPercentDiscount">
				   							<xsl:value-of select="./cell[@column=$bundled.bid.column + 2]"/>
				   						</xsl:attribute>
				   						<xsl:attribute name="BidType">
				   							<xsl:value-of select="java:getValue($language, 'integration.BidType.SimpleBid')"/>
				   						</xsl:attribute>
				   						<xsl:attribute name="BidPPUDiscountType">
				   							<xsl:value-of select="java:getValue($language, 'excelmap.bids.bundle.ppu.discounttype.percent')"/>
				   						</xsl:attribute>
				   						<xsl:attribute name="BidOTCDiscountType">
				   							<xsl:value-of select="java:getValue($language, 'excelmap.bids.bundle.otc.discounttype.percent')"/>
				   						</xsl:attribute>
				   						<xsl:apply-templates select="./cell[(number(@column) &gt;= ($org.bid.offset + 2)) and 
				   						                             (number(@column) &lt; $SimpleBidEndColumn)]" mode="ExtendAttributes"/>
				   						<xsl:call-template name="LogRows">
												<xsl:with-param name="rowNum" select="$rowNum"/>
										</xsl:call-template>
				   					</xsl:element>
				   				</xsl:if>
				   			</xsl:if>
		   				 </xsl:for-each>
	    			</xsl:otherwise>
	    		</xsl:choose>	    		
    		</xsl:element>
    	</saxon:while>
   </xsl:template>
   
   <!-- log row ID for error reporting-->
   <xsl:template name="LogRows">
   		<xsl:param name="rowNum"/>
        <xsl:element name="Logs">
            <xsl:attribute name="rowID">
                <xsl:value-of select="$rowNum"/>
            </xsl:attribute>
        </xsl:element>
    </xsl:template>
    
    <!-- Process extended attribute for volume bid except min and max attribute -->
	<xsl:template match="cell" mode="VolumeBidXtendedAttribute">		
		<xsl:call-template name="VolumeBidExtendedAttribute">
             <xsl:with-param name="header" select="$bidtemplate.bid.header"/>
   	    </xsl:call-template>
	</xsl:template>
	
	<!-- Process an extended attribute for volume bid -->
    <xsl:template name="VolumeBidExtendedAttribute">
        <xsl:param name="header" select="."/>
        <!-- check for empty header to strip out error messages -->        
        <xsl:if test="./node() and ($header/cell[@column=current()/@column]) and
        		      $header/cell[@column=current()/@column] != java:getValue($language, 'excelmap.bids.simple.BidMaximum') and
        		      $header/cell[@column=current()/@column] != java:getValue($language, 'excelmap.bids.simple.BidMinimum')">
            <!-- remove leading * in the column header if present -->
            <xsl:element name="ExtendedAttribute">
                <xsl:attribute name="ExtendedAttributeCode">
                    <!-- remove leading * in the column header if present -->
                    <xsl:choose>
                        <xsl:when test="starts-with($header/cell[@column=current()/@column], '*')">
                        	<xsl:choose>
                        		<xsl:when test="$header/cell[@column=current()/@column] = java:getValue($language,'excelmap.bidfield.discount.value.mandatory')">
                        			<xsl:value-of select="java:getValue($language,'term.pricePerUnitDiscountValue')"/>
                        		</xsl:when>
                        		<xsl:otherwise>
                        			<xsl:value-of select="substring($header/cell[@column=current()/@column],2)"/>
                        		</xsl:otherwise>
                        	</xsl:choose>                            
                        </xsl:when>
                        <xsl:otherwise>
                        	<xsl:choose>
                        		<xsl:when test="$header/cell[@column=current()/@column] = java:getValue($language,'excelmap.bidfield.discount.value')">
                        			<xsl:value-of select="java:getValue($language,'term.pricePerUnitDiscountValue')"/>
                        		</xsl:when>
                        		<xsl:otherwise>
                        			<xsl:value-of select="$header/cell[@column=current()/@column]"/>
                        		</xsl:otherwise>
                        	</xsl:choose>                            
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:attribute>
                <xsl:attribute name="ExtendedAttributeValue">
                    <!-- PR8311: Process XAs defined as date type.
                         For each potential type of XA (lineitem/bid/catalog/category/organization/business_user),
                         check if the XACode exists in the DateXACodesKey.  If true, process Excel date format.
                         The check for substring is needed to stripe off * from required XACode.
                         As of ePASS3.6, only bid has intelligent attribute which can define data type of date,
                         lineitem/catalog/category will be added in 3.7 -->
                    <xsl:variable name="attributeName" select="$header/cell[@column=current()/@column]"/>
                    <xsl:choose>
                        <!-- lineitem Date XA -->
                        <xsl:when test="$header/cell[@column='1'] = java:getValue($language,'excelmap.rfx.item.LineItemName')
                                and (key('lineitemDateXACodesKey', $attributeName)
                                or (key('lineitemDateXACodesKey', substring($attributeName, 2))))">
                            <xsl:call-template name="ProcessDate"/>
                        </xsl:when>
                        <!-- bid Date XA -->
                        <xsl:when test="$header/cell[@column='1'] = java:getValue($language,'excelmap.bids.bids.BidType')
                                and (key('bidDateXACodesKey', $attributeName)
                                or (key('bidDateXACodesKey', substring($attributeName, 2))))">
                            <xsl:call-template name="ProcessDate"/>
                        </xsl:when>
                        <!-- catalog/category Date XA -->
                        <!-- Enabled in 3.7: since both catalog/category XAs apply to products ONLY,
                             needed to merge the two keys catalog/category into one -->
                        <xsl:when test="($header/cell[@column='1'] = 'ProductName'
                                or substring($header/cell[@column='1'], 2) = 'ProductName')
                                and (key('categoryDateXACodesKey', $attributeName)
                                or (key('categoryDateXACodesKey', substring($attributeName, 2))))">
                            <xsl:call-template name="ProcessDate"/>
                        </xsl:when>
                        <!-- task Date XA -->
                        <xsl:when test="$header/cell[@column='1'] = java:getValue($language,'excelmap.project.task.TaskName')
                                and (key('taskDateXACodesKey', $attributeName)
                                or (key('taskDateXACodesKey', substring($attributeName, 2))))">
                            <xsl:call-template name="ProcessDate"/>
                        </xsl:when>
                        <!-- any Date XA not defined in XAD section (ICAs) -->
                        <xsl:when test="contains($attributeName, 'Date') or contains($attributeName, 'date')">
                            <xsl:call-template name="ProcessDate"/>
                        </xsl:when>
                        <!-- non-Date XAs: output value -->
                        <xsl:otherwise>
                            <xsl:call-template name="concatSubcell"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:attribute>
                <xsl:call-template name="logRowId"/>
            </xsl:element>
        </xsl:if>
    </xsl:template>
</xsl:stylesheet>

<!--
 * $Log: /epass/epass5.0.1/com/avinamart/WebInterface/public_html/Integration/xsl/gXML2ePASS/gXML2ePASS_Bid.xsl $
 *
 * 2     10/14/04 3:46p Djesurum
 * PR-21468,9: restore surrogate bidding for all rfx types except survey.
 *
 * 40    5/24/04 5:23p Djesurum
 * Use mapDir variable to locate locale specific header map document.
 *
 * 39    5/03/04 11:10a Djesurum
 * Correct typo (missing @) accompanying last change.
 *
 * 38    4/22/04 5:36p Djesurum
 * PR-21907:  Change Response row template to check column3 as-well-as
 * column1.
 *
 * 37    4/21/04 11:07a Djesurum
 * Change Response template to ignore responses without questionnaires.
 *
 * 36    4/20/04 5:33p Djesurum
 * PR-21840:  Import all response rows if the either the answer or comment
 * is null or not XXXXX.
 *
 * 35    4/04/04 10:33p Djesurum
 * Change bidtemplate.instr.row to look for sec1.sup.all.header or
 * sec1.org.all.header.
 *
 * 34    3/29/04 6:11p Djesurum
 * Change org.bid.offset for surrogate standard from 10 to 9 since
 * preliminary bid is only for advanced.
 *
 * 33    3/23/04 10:44a Djesurum
 * PR-21133.  Correct createBids row template to not include row boundary
 * in bid/response area.
 *
 * 32    3/12/04 9:38a Djesurum
 * Use mapBase to check rfxType value instead of mapRFx.
 *
 * 31    2/10/04 5:32p Djesurum
 * Add capability of importing Responses, depending on RFxType.
 *
 * 30    1/21/04 1:47p Djesurum
 * Aesthetic formatting changes.
 *
 * 29    1/19/04 2:22p Djesurum
 * Rename RFQCode header to RFxCode.
 *
 * 28    10/21/03 3:05p Xxu
 * persists rowID in Logs element for error reporting
 *
 * 27    10/07/03 11:06a Cpate
 * Fixing PR12501: Adding description column.
 *
 * 25    6/30/03 2:34p Stardif
 * PR16074:HOTSPOT#192: RFI Import->XSLT Transformation is excessively
 * slow/unscalable. Just removed useless comment.
 *
 * 24    6/05/03 9:17a Cpate
 * Rolling back changes.
 *
 * 22    5/30/03 10:08a Cpate
 * Fixing PR14311: Filtering out bids from template that do not have
 * values.
 *
 * 21    5/07/03 7:14p Xxu
 * remove two instances of variables in xsl:template which is not allowed
 *
 * 20    4/25/03 11:25a Cpate
 * Fixing PR14722: Adding currency code to RFx export for bid temp
 *
 * 18    3/26/03 7:40p Xxu
 * PR13577: reference cell by @column to handle XLS columns out of
 * sequence
 *
 * 17    3/04/03 8:31p Xxu
 * PR13308: find last row to be processed with or without instruction rows
 *
 * 16    1/13/03 4:05p Cpate
 * Fixing parsing problem.
 *
 * 15    12/11/02 4:09p Cpate
 * Adding import handling for new bid template.
 *
 * 12    5/09/02 11:56a Xxu
 * PR8311: process IBAs from Excel date format
 *
 * 11    5/03/02 4:53p Cpate
 * Fixing incoming processing to handle added columns in format for Bid.
 *
 * 10    1/31/02 11:11a Xxu
 * Support column header masking
 *
 * 9     1/29/02 5:45p Xxu
 * Moved mapping code to shared location and tidy up code no longer needed
 *
 * 8     1/25/02 2:54p Xxu
 * Support Excel templates masked with user friendly column names
-->
