<!--
 (C) COPYRIGHT International Business Machines Corp. 2012, 2015. All Rights Reserved
  US Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0"
    xmlns:saxon="http://saxon.sf.net/"
    xmlns:java="java:com.avinamart.Utility.EPASSIFHelper"
    exclude-result-prefixes="saxon java"  extension-element-prefixes="saxon">
    
    <xsl:variable name="rfxInfoRow" select="book/sheet/range/row[@row='2']"/>

    <!-- Find table question response row. Rows after this are not to be read -->
    <xsl:variable name="tableInfoRow"
            	select="book/sheet/range/row[cell[@column='1'] = java:getValue($language,'integration.MatrixQuestionResponses')]/@row"/>
    <xsl:variable name="RFxtype" select="java:getName($language, $rfxInfoRow/cell[@column='4'], 'integration.AuctionType.')"/>      	
    
     <!-- **************************************************** -->
    <!-- Create score section specific for converting to ePASS XML -->
    <!-- **************************************************** -->
    <xsl:template match="row" mode="createScore">
        <xsl:element name="createScore">
            <!-- attributes for createScore element -->
            <xsl:attribute name="OrganizationCode">
                <xsl:value-of select="$rfxInfoRow/cell[@column='1']"/>
            </xsl:attribute>
            <xsl:attribute name="RFxName">
                <xsl:value-of select="$rfxInfoRow/cell[@column='2']"/>
            </xsl:attribute>
            <xsl:attribute name="RFxCode">
                <xsl:value-of select="$rfxInfoRow/cell[@column='3']"/>
            </xsl:attribute>
             <xsl:attribute name="ScorerUser">
                <xsl:value-of select="$rfxInfoRow/cell[@column='6']"/>
            </xsl:attribute>
                 
            <!-- Process Scores. Consider rows only up to Table Question Responses row -->
            <xsl:choose>
            	<xsl:when test="$tableInfoRow != ''">
            		<xsl:apply-templates
                    select="following-sibling::row[number(@row) &gt; 4 and number(@row) &lt; number($tableInfoRow)]" mode="Score"/>
            	</xsl:when>
            	<xsl:otherwise>
            		<xsl:apply-templates
                    select="following-sibling::row[number(@row) &gt; 4]" mode="Score"/>
            	</xsl:otherwise>
            </xsl:choose>
      	</xsl:element>
    </xsl:template>
    
    <xsl:template match="row" mode="Score">
     	<xsl:element name="Score">
     		<xsl:attribute name="ScoreQuestionnaire"><xsl:value-of select="cell[@column=1]"/></xsl:attribute>
     		<xsl:attribute name="ScoreQuestion"><xsl:value-of select="cell[@column=2]"/></xsl:attribute>
     		<xsl:choose>
     			<xsl:when test="$RFxtype = 'buyer_rfi'">
     				<xsl:attribute name="ResponseSubmitterLogin"><xsl:value-of select="cell[@column=3]"/></xsl:attribute>
     				<xsl:if test="cell[@column=10]">
     					<xsl:attribute name="MyScore"><xsl:value-of select="cell[@column=10]"/></xsl:attribute>
     				</xsl:if>
     				<xsl:if test="cell[@column=11]">
		     			<xsl:attribute name="MyComments"><xsl:value-of select="cell[@column=11]"/></xsl:attribute>
		     		</xsl:if>
		     		<xsl:if test="cell[@column=12]">
		     			<xsl:attribute name="OverrideScore"><xsl:value-of select="cell[@column=12]"/></xsl:attribute>
		     		</xsl:if>
		     		<xsl:if test="cell[@column=13]">
		     			<xsl:attribute name="OverrideScoreComments"><xsl:value-of select="cell[@column=13]"/></xsl:attribute>
		     		</xsl:if>
     			</xsl:when>
     			<xsl:otherwise>
     				<xsl:attribute name="ScoreSupplier"><xsl:value-of select="cell[@column=3]"/></xsl:attribute>
     				<xsl:attribute name="ScoreSupplierVsmId"><xsl:value-of select="cell[@column=4]"/></xsl:attribute>
		     		<xsl:attribute name="ScoreSupplierLogin"><xsl:value-of select="cell[@column=5]"/></xsl:attribute>
		     		<xsl:if test="cell[@column=13]">
     					<xsl:attribute name="MyScore"><xsl:value-of select="cell[@column=13]"/></xsl:attribute>
     				</xsl:if>
     				<xsl:if test="cell[@column=14]">
		     			<xsl:attribute name="MyComments"><xsl:value-of select="cell[@column=14]"/></xsl:attribute>
		     		</xsl:if>
		     		<xsl:if test="cell[@column=15]">
		     			<xsl:attribute name="OverrideScore"><xsl:value-of select="cell[@column=15]"/></xsl:attribute>
		     		</xsl:if>
		     		<xsl:if test="cell[@column=16]">
		     			<xsl:attribute name="OverrideScoreComments"><xsl:value-of select="cell[@column=16]"/></xsl:attribute>
		     		</xsl:if>
     			</xsl:otherwise>
     		</xsl:choose>
     		
     		<xsl:call-template name="logRowId"/>
     	</xsl:element>
     </xsl:template>
   
</xsl:stylesheet>
	

