<!--
 (C) COPYRIGHT International Business Machines Corp. 2012, 2016. All Rights Reserved
  US Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-->
<xsl:stylesheet xmlns:p="ted/R2.0.9.S02/reception" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format"
	xmlns:messageLocalizer="java:com.emptoris.app.ojeu.integration.PDFMessageLocalizer" version="2.0" xmlns:saxon="http://saxon.sf.net/"
	xmlns:emptoris-ojeu="http://www.emptoris.com/sourcing/ojeu" extension-element-prefixes="saxon">
	
	<xsl:template name="Section_AwardOfContract_CONTRACT_AWARD">
		<xsl:param name="noticeRoot" />
		<xsl:param name="contractsAwarded" select="()" />

		<xsl:for-each select="$contractsAwarded">
			<fo:block xsl:use-attribute-sets="h1" break-before="page">
				<xsl:value-of
					select="
					if( last() > 1 ) 
					then 
						concat(messageLocalizer:convertLiteral($locale,'form.noticetree.notice_award_of_contract'),' (',position(),') ') 
					else 
						messageLocalizer:convertLiteral($locale,'form.noticetree.notice_award_of_contract') 
					" />
			</fo:block>
			<xsl:variable name="contractAwardedYes" select="p:AWARDED_CONTRACT" />
			<xsl:variable name="contractAwardedNo" select="p:NO_AWARDED_CONTRACT" />
			<fo:block-container xsl:use-attribute-sets="subSectionBox">
				<xsl:call-template name="writeSimpleFieldsLabelAboveValueBelow">
					<xsl:with-param name="contextNode" select="." />
					<xsl:with-param name="relativeXPaths" select="( 'p:CONTRACT_NO')" />
					<xsl:with-param name="resourceBundleKeys" select="( 'ojeu.form.award_contract.no.hdr' )" />
					<xsl:with-param name="marginLeft" select="'0mm'" />
					<xsl:with-param name="numEmptyLinesIfBlank" select="1" />
				</xsl:call-template>
				<xsl:variable name="contractTitle" select="./p:TITLE"/>
				<xsl:variable name="lotNumber" select="./p:LOT_NO"/>
				
				<fo:table table-layout="fixed" xsl:use-attribute-sets="h3" font-weight="normal" margin-top="5mm" width="100mm">
					<fo:table-column column-width="70mm" />
					<fo:table-column column-width="30mm" />
					<fo:table-header>
						<fo:table-row>
							<fo:table-cell><fo:block font-weight="bold"><xsl:value-of select="'Contract Title'" /></fo:block></fo:table-cell>
							<fo:table-cell><fo:block font-weight="bold"><xsl:value-of select="'Lot Number'" /></fo:block></fo:table-cell>
						</fo:table-row>
					</fo:table-header>
					<fo:table-body>
						
						<xsl:variable name="loopCount" select="if($contractTitle) then count($contractTitle) else 1" />
						<xsl:for-each select="(1 to $loopCount)">
							<xsl:variable name="currentPosition" select="position()" />
							<fo:table-row>
								<fo:table-cell>
									<xsl:call-template name="writeSingleLineData"><xsl:with-param name="singleLineData" select="$contractTitle[$currentPosition]" /></xsl:call-template>									
								</fo:table-cell>
								<fo:table-cell >
									<xsl:call-template name="writeSingleLineData"><xsl:with-param name="singleLineData" select="$lotNumber[$currentPosition]" /></xsl:call-template>									
								</fo:table-cell>
							</fo:table-row>
						</xsl:for-each>
					</fo:table-body>
				</fo:table>
				
				<fo:block xsl:use-attribute-sets="h3" margin-top="2mm">
					<xsl:value-of select="messageLocalizer:convertLiteral($locale,'ojeu.form.detail.contract_award.hdr.lot.awarded')" />
				</fo:block>
				<xsl:call-template name="writeSingleLineData">
					<xsl:with-param name="singleLineData" select="messageLocalizer:convertLiteral($locale,if( $contractAwardedNo ) then 'form.terminology.button.no' else 'form.terminology.button.yes' )" />
					<xsl:with-param name="marginLeft" select="'0mm'" />
				</xsl:call-template>
				
				<xsl:if test="$contractAwardedYes">
					<fo:block xsl:use-attribute-sets="h3" margin-top="2mm">
						<xsl:value-of select="messageLocalizer:convertLiteral($locale,'ojeu.form.detail.contract_award.hdr.date')" />
					</fo:block>
					<xsl:call-template name="writeSingleLineData">
						<xsl:with-param name="singleLineData" select="p:AWARDED_CONTRACT/p:DATE_CONCLUSION_CONTRACT" />
						<xsl:with-param name="marginLeft" select="'0mm'" />
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="$contractAwardedNo">
					<xsl:variable name="procurementDiscontinued" select="$contractAwardedNo/p:PROCUREMENT_DISCONTINUED" />
					<fo:block xsl:use-attribute-sets="h3" margin-top="2mm">
						<xsl:value-of select="messageLocalizer:convertLiteral($locale,'ojeu.form.detail.contract_award.hdr.lot.not.awarded')" />
					</fo:block>
					<xsl:call-template name="writeSingleLineData">
						<xsl:with-param name="singleLineData" select="messageLocalizer:convertLiteral($locale,if($contractAwardedNo/p:PROCUREMENT_UNSUCCESSFUL) then 'ojeu.form.detail.contract_award.hdr.lot.not.awarded.option1' else if($contractAwardedNo/p:PROCUREMENT_DISCONTINUED) then 'ojeu.form.detail.contract_award.hdr.lot.not.awarded.option2' else '')" />
						<xsl:with-param name="marginLeft" select="'0mm'" />
					</xsl:call-template>
					<xsl:if test="$procurementDiscontinued">
						<fo:block xsl:use-attribute-sets="h3" margin-top="2mm">
							<xsl:value-of select="messageLocalizer:convertLiteral($locale,'ojeu.form.detail.contract_award.hdr.lot.not.awarded.noticeReference')" />
						</fo:block>
						<xsl:call-template name="writeSingleLineData">
							<xsl:with-param name="singleLineData" select="$procurementDiscontinued/p:NO_DOC_EXT" />
							<xsl:with-param name="marginLeft" select="'0mm'" />
						</xsl:call-template>
					</xsl:if>
				</xsl:if>
			</fo:block-container>
			
						
			<xsl:if test="$contractAwardedYes">
				<fo:block xsl:use-attribute-sets="h3" margin-left="2mm">
					<xsl:value-of select="messageLocalizer:convertLiteral($locale,'ojeu.form.detail.contract_award.header.information.about.tenders')" />
				</fo:block>
				<fo:block-container xsl:use-attribute-sets="subSectionBox">
					<xsl:call-template name="writeSimpleFieldsLabelAboveValueBelow">
						<xsl:with-param name="contextNode" select="." />
						<xsl:with-param name="relativeXPaths" select="( 'p:AWARDED_CONTRACT/p:NB_TENDERS_RECEIVED' )" />
						<xsl:with-param name="resourceBundleKeys" select="( 'ojeu.form.detail.contract_award.hdr.no_offers_received' )" />
						<xsl:with-param name="marginLeft" select="'0mm'" />
						<xsl:with-param name="numEmptyLinesIfBlank" select="1" />
					</xsl:call-template>
					<xsl:call-template name="writeSimpleFieldsLabelAboveValueBelow">
						<xsl:with-param name="contextNode" select="." />
						<xsl:with-param name="relativeXPaths" select="( 'p:AWARDED_CONTRACT/p:NB_TENDERS_RECEIVED_SME' )" />
						<xsl:with-param name="resourceBundleKeys" select="( 'ojeu.form.detail.contract_award.hdr.no_offers_received_frm_smes' )" />
						<xsl:with-param name="marginLeft" select="'0mm'" />
						<xsl:with-param name="numEmptyLinesIfBlank" select="1" />
					</xsl:call-template>
					<xsl:call-template name="writeSimpleFieldsLabelAboveValueBelow">
						<xsl:with-param name="contextNode" select="." />
						<xsl:with-param name="relativeXPaths" select="( 'p:AWARDED_CONTRACT/p:NB_TENDERS_RECEIVED_OTHER_EU' )" />
						<xsl:with-param name="resourceBundleKeys" select="( 'ojeu.form.detail.contract_award.hdr.no_offers_received_frm_otherEU' )" />
						<xsl:with-param name="marginLeft" select="'0mm'" />
						<xsl:with-param name="numEmptyLinesIfBlank" select="1" />
					</xsl:call-template>
					<xsl:call-template name="writeSimpleFieldsLabelAboveValueBelow">
						<xsl:with-param name="contextNode" select="." />
						<xsl:with-param name="relativeXPaths" select="( 'p:AWARDED_CONTRACT/p:NB_TENDERS_RECEIVED_NON_EU' )" />
						<xsl:with-param name="resourceBundleKeys" select="( 'ojeu.form.detail.contract_award.hdr.no_offers_received_frm_nonEU' )" />
						<xsl:with-param name="marginLeft" select="'0mm'" />
						<xsl:with-param name="numEmptyLinesIfBlank" select="1" />
					</xsl:call-template>
					<xsl:call-template name="writeSimpleFieldsLabelAboveValueBelow">
						<xsl:with-param name="contextNode" select="." />
						<xsl:with-param name="relativeXPaths" select="( 'p:AWARDED_CONTRACT/p:NB_TENDERS_RECEIVED_EMEANS' )" />
						<xsl:with-param name="resourceBundleKeys" select="( 'ojeu.form.detail.contract_award.hdr.no_offers_received_frm_otherEU_electronic_means' )" />
						<xsl:with-param name="marginLeft" select="'0mm'" />
						<xsl:with-param name="numEmptyLinesIfBlank" select="1" />
					</xsl:call-template>
					<xsl:call-template name="writeSimpleFieldsLabelAboveValueBelow">
						<xsl:with-param name="contextNode" select="." />
						<xsl:with-param name="relativeXPaths" select="( 'p:AWARDED_CONTRACT/p:NB_TENDERS_RECEIVED_EMEANS' )" />
						<xsl:with-param name="resourceBundleKeys" select="( 'ojeu.form.detail.contract_award.hdr.no_offers_received_frm_otherEU_electronic_means' )" />
						<xsl:with-param name="marginLeft" select="'0mm'" />
						<xsl:with-param name="numEmptyLinesIfBlank" select="1" />
					</xsl:call-template>
					<fo:block xsl:use-attribute-sets="h3" margin-top="2mm">
						<xsl:value-of select="messageLocalizer:convertLiteral($locale,'ojeu.form.detail.contract_award.hdr.awarded_grp_economic_operators')" />
					</fo:block>
					<xsl:call-template name="writeSingleLineData">
						<xsl:with-param name="singleLineData" select="messageLocalizer:convertLiteral($locale,if( $contractAwardedYes/p:AWARDED_TO_GROUP ) then 'form.terminology.button.yes' else 'form.terminology.button.no' )" />
						<xsl:with-param name="marginLeft" select="'0mm'" />
					</xsl:call-template>
				</fo:block-container>
				
				<fo:block-container break-before="page">
					<xsl:variable name="contractors" select="p:AWARDED_CONTRACT/p:CONTRACTOR" />
					<xsl:for-each select="$contractors"> 
						<xsl:variable name="contractorSME" select="./p:SME" />
						<fo:block xsl:use-attribute-sets="h3" margin-left="2mm">
							<xsl:value-of select="if( last() > 1 ) then concat(messageLocalizer:convertLiteral($locale,'ojeu.form.detail.contract_award.hdr.name_address_awardee_hdr'),' (',position(),') ') else messageLocalizer:convertLiteral($locale,'ojeu.form.detail.contract_award.hdr.name_address_awardee_hdr')" />
						</fo:block>
						<xsl:call-template name="writeContactDetails">
							<xsl:with-param name="contextNode" select="./p:ADDRESS_CONTRACTOR" />
							<xsl:with-param name="displayContactPoints" select="false()" />
							<xsl:with-param name="displayURL" select="true()" />
							<xsl:with-param name="showSME" select="true()" />
							<xsl:with-param name="isSME" select="messageLocalizer:convertLiteral($locale,if( $contractorSME ) then 'form.terminology.button.yes' else 'form.terminology.button.no' )" />
						</xsl:call-template>
					</xsl:for-each>
				</fo:block-container>
			
				<fo:block xsl:use-attribute-sets="h3" margin-left="2mm">
					<xsl:value-of select="messageLocalizer:convertLiteral($locale,'ojeu.form.detail.contract_award.hdr.info_value_of_contract')" />
				</fo:block>
				<fo:block-container xsl:use-attribute-sets="subSectionBox">
					<xsl:variable name="contractTotalValue" select="p:AWARDED_CONTRACT/p:VAL_TOTAL" />
					<xsl:variable name="contractIniEstimates" select="p:AWARDED_CONTRACT/p:VAL_ESTIMATED_TOTAL" />
					<xsl:variable name="rangeValue" select="p:AWARDED_CONTRACT/p:VAL_RANGE_TOTAL" />
					<xsl:variable name="rangeValueMin" select="p:AWARDED_CONTRACT/p:VAL_RANGE_TOTAL/p:LOW" />
					<xsl:variable name="rangeValueMax" select="p:AWARDED_CONTRACT/p:VAL_RANGE_TOTAL/p:HIGH" />
					
					<fo:block xsl:use-attribute-sets="h3" margin-top="2mm">
						<xsl:value-of select="messageLocalizer:convertLiteral($locale,'ojeu.form.detail.contract_award.hdr.ini_esti_value_of_contract')" />
					</fo:block>
					<xsl:call-template name="writeSingleLineData">
						<xsl:with-param name="singleLineData" select="$contractIniEstimates" />
						<xsl:with-param name="marginLeft" select="'0mm'" />
					</xsl:call-template>

					<xsl:if test="$contractTotalValue">
						<fo:block xsl:use-attribute-sets="h3" margin-top="2mm">
							<xsl:value-of select="messageLocalizer:convertLiteral($locale,'ojeu.form.detail.contract_award.hdr.total_final_value_of_contract')" />
						</fo:block>
						<xsl:call-template name="writeSingleLineData">
							<xsl:with-param name="singleLineData" select="$contractTotalValue" />
							<xsl:with-param name="marginLeft" select="'0mm'" />
						</xsl:call-template>
					</xsl:if>
					
					<xsl:if test="$rangeValue">
						<fo:block xsl:use-attribute-sets="h3" margin-top="2mm">
							<xsl:value-of select="messageLocalizer:convertLiteral($locale,'ojeu.form.detail.contract_award.hdr.contract_final_value_hdr_lowest_offer')" />
						</fo:block>
						<xsl:call-template name="writeSingleLineData">
							<xsl:with-param name="singleLineData" select="$rangeValueMin" />
							<xsl:with-param name="marginLeft" select="'0mm'" />
						</xsl:call-template>
						<fo:block xsl:use-attribute-sets="h3" margin-top="2mm">
							<xsl:value-of select="messageLocalizer:convertLiteral($locale,'ojeu.form.detail.contract_award.hdr.contract_final_value_hdr_highest_offer.pdf')" />
						</fo:block>
						<xsl:call-template name="writeSingleLineData">
							<xsl:with-param name="singleLineData" select="$rangeValueMax" />
							<xsl:with-param name="marginLeft" select="'0mm'" />
						</xsl:call-template>						
					</xsl:if>
				</fo:block-container>
				
				<fo:block xsl:use-attribute-sets="h3" margin-top="2mm">
					<xsl:value-of select="messageLocalizer:convertLiteral($locale,'ojeu.form.detail.contract_award.main_hdr.likely_to_subcontracted')" />
				</fo:block>
				<fo:block-container xsl:use-attribute-sets="subSectionBox" break-after="{if(position()=last()) then 'page' else 'auto'}">
					<xsl:variable name="isSubcontracted" select="p:AWARDED_CONTRACT/p:LIKELY_SUBCONTRACTED" />
					
					<fo:block xsl:use-attribute-sets="h3" margin-top="2mm">
						<xsl:value-of select="messageLocalizer:convertLiteral($locale,'ojeu.form.detail.contract_award.hdr.likely_to_subcontracted')" />
					</fo:block>
					<xsl:call-template name="writeSingleLineData">
						<xsl:with-param name="singleLineData" select="messageLocalizer:convertLiteral($locale,if( $isSubcontracted ) then 'form.terminology.button.yes' else 'form.terminology.button.no' )" />
						<xsl:with-param name="marginLeft" select="'0mm'" />
					</xsl:call-template>

					<xsl:if test="$isSubcontracted">
						<xsl:variable name="subcontractingValue" select="p:AWARDED_CONTRACT/p:VAL_SUBCONTRACTING" />
						<xsl:variable name="subcontractingPrct" select="p:AWARDED_CONTRACT/p:PCT_SUBCONTRACTING" />
						<fo:block xsl:use-attribute-sets="h3" margin-top="2mm">
							<xsl:value-of select="messageLocalizer:convertLiteral($locale,'ojeu.form.detail.contract_award.main_hdr.likely_to_subcontracted.vat')" />
						</fo:block>
						<xsl:call-template name="writeSingleLineData">
							<xsl:with-param name="singleLineData" select="$subcontractingValue" />
							<xsl:with-param name="marginLeft" select="'0mm'" />
						</xsl:call-template>
						<fo:block xsl:use-attribute-sets="h3" margin-top="2mm">
							<xsl:value-of select="messageLocalizer:convertLiteral($locale,'SubContractType.Proportion')" />
						</fo:block>
						<xsl:call-template name="writeSingleLineData">
							<xsl:with-param name="singleLineData" select="$subcontractingPrct" />
							<xsl:with-param name="marginLeft" select="'0mm'" />
						</xsl:call-template>
						<fo:block xsl:use-attribute-sets="h3" margin-top="2mm">
							<xsl:value-of select="messageLocalizer:convertLiteral($locale,'ojeu.form.detail.contract_award.hdr.short_desc_of_subcontracted')" />
						</fo:block>
						<xsl:call-template name="writeMultiLineData">
							<xsl:with-param name="multiLineData" select="p:AWARDED_CONTRACT/p:INFO_ADD_SUBCONTRACTING" />
							<xsl:with-param name="marginLeft" select="'0mm'" />
						</xsl:call-template>
					</xsl:if>
				</fo:block-container>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>	
</xsl:stylesheet>
