<!--
 (C) COPYRIGHT International Business Machines Corp. 2012, 2016. All Rights Reserved
  US Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-->
<xsl:stylesheet xmlns:p="ted/R2.0.9.S02/reception" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:fo="http://www.w3.org/1999/XSL/Format"
	xmlns:messageLocalizer="java:com.emptoris.app.ojeu.integration.PDFMessageLocalizer"
	version="2.0" xmlns:saxon="http://saxon.sf.net/" xmlns:emptoris-ojeu="http://www.emptoris.com/sourcing/ojeu"  extension-element-prefixes="saxon"
	>
	<!--
		In SAXON 8.3, only global variables can be marked as assignable. It'd be nice if local variables as assignable. Need
		to investigate further with SAXON.
	-->
	<xsl:template name="Section_ContractingAuthority">
		<xsl:param name="sectionRoot" />
		<xsl:param name="PinType" />
		<xsl:param name="noticeType" />
		<xsl:param name="noticeRoot" />
		<xsl:if test="($noticeType !='CORRIGENDUM')">
			<xsl:call-template name="Section_ContractingAuthority_NOT_CORRIGENDUM" >
				<xsl:with-param name="sectionRoot" select="$sectionRoot" />
				<xsl:with-param name="PinType" select="$PinType" />
				<xsl:with-param name="noticeType" select="$noticeType" />
				<xsl:with-param name="noticeRoot" select="$noticeRoot" />
			</xsl:call-template>	
		</xsl:if>
		<xsl:if test="($noticeType ='CORRIGENDUM')">
			<xsl:call-template name="Section_ContractingAuthority_CORRIGENDUM" >
				<xsl:with-param name="sectionRoot" select="$sectionRoot" />
				<xsl:with-param name="noticeRoot" select="$noticeRoot" />
			</xsl:call-template>	
		</xsl:if>		
	</xsl:template>
	
	<xsl:template name="Section_ContractingAuthority_NOT_CORRIGENDUM" >
		<xsl:param name="sectionRoot" />
		<xsl:param name="PinType" />
		<xsl:param name="noticeType" />
		<xsl:param name="noticeRoot" />
		<!--<xsl:variable name="root" select="$sectionRoot/p:ADDRESS_CONTRACTING_BODY" />-->
		<xsl:variable name="noticeNumberAndPublicationDateRoot" select="$noticeRoot/p:OJ_NUMBER_AFTER_PUBLISH"/>
	
			<!--  Section Title -->
		<fo:block xsl:use-attribute-sets="h1">
			<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.noticetree.contracting_authority')" />
		</fo:block>
		
	
		<!-- Name, address, contact details, internert information and other detail further information -->
		<saxon:assign name="relativeXPaths" select="(
			'ORGANISATION','ADDRESS','TOWN','POSTAL_CODE','@COUNTRY-NAME','CONTACT_POINT','ATTENTION','PHONE','E_MAILS','FAX','URL'
		)" />
		
		<saxon:assign name="resourceBundleKeys" select="(
			'form.wiz_notice_annexa.header.notice.official.name',
			'form.wiz_notice_annexa.header.notice.postal.address',
			'form.wiz_notice_annexa.header.notice.town',
			'form.wiz_notice_annexa.header.notice.postal.code',
			'form.wiz_notice_annexa.header.notice.country',
			'form.wiz_notice_annexa.header.notice.contact.points',
			'form.wiz_notice_annexa.header.notice.attention',
			'form.wiz_notice_annexa.header.notice.telephone',
			'form.wiz_notice_annexa.header.notice.email',
			'form.wiz_notice_annexa.header.notice.fax',
			'form.wiz_notice_annexa.header.notice.url'
		)" />
		
	
			<xsl:if test="$noticeNumberAndPublicationDateRoot">
				<fo:block xsl:use-attribute-sets="h2">
					<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_ca.notice.publication.details')" />
				</fo:block>
			<fo:block-container xsl:use-attribute-sets="subSectionBox">
				<fo:block xsl:use-attribute-sets="h3"  margin-top="2mm">
					<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_contracting_authority.header.notice.reference.number')" />
				</fo:block>
				<fo:block xsl:use-attribute-sets="h3" font-weight="normal"  margin-top="2mm">
					<xsl:value-of select="$noticeNumberAndPublicationDateRoot/p:NOTICE_NUMBER_OJ" />
				</fo:block>
				
				<fo:block xsl:use-attribute-sets="h3"  margin-top="2mm">
					<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_contracting_authority.header.notice.date.of.publication')" />
				</fo:block>
				<fo:block xsl:use-attribute-sets="nonBold" >
					<xsl:value-of select="$noticeNumberAndPublicationDateRoot/p:DATE_OJ/@DESCRIPTION" />
				</fo:block>
			</fo:block-container>
		</xsl:if>
		
		
		<!--  Sub Section Title -->
		<fo:block xsl:use-attribute-sets="h2">
			<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_contracting_authority.header.notice.name.address.and.contact.point')" />
		</fo:block>
		
		<xsl:call-template name="writeContactDetails">
			<xsl:with-param name="contextNode" select="$sectionRoot/p:ADDRESS_CONTRACTING_BODY" />
		</xsl:call-template>
		

		<xsl:for-each select="$sectionRoot/p:ADDRESS_CONTRACTING_BODY_ADDITIONAL"> 
			<fo:block xsl:use-attribute-sets="h2">
				<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_contracting_authority.header.notice.name.address.and.contact.point')" />
			</fo:block>
			<xsl:call-template name="writeContactDetails">
				<xsl:with-param name="contextNode" select="." />
			</xsl:call-template>
		</xsl:for-each>
			
		
		<fo:block-container keep-together.within-page="auto">
			<fo:block xsl:use-attribute-sets="h2" >
				<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_contracting_authority.header.notice.joint.procurement')" />
			</fo:block>
			<fo:block-container xsl:use-attribute-sets="subSectionBox">
				<fo:block xsl:use-attribute-sets="h3"  margin-top="2mm">
					<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiznoticestart.header.jointProcurement')" />
				</fo:block>
				<fo:block xsl:use-attribute-sets="h3" font-weight="normal"  margin-top="2mm">
					<xsl:call-template name="writeSingleLineData">
						<xsl:with-param name="singleLineData" select="
							if( $sectionRoot/p:JOINT_PROCUREMENT_INVOLVED ) then messageLocalizer:convertLiteral($locale,'form.terminology.button.yes')
							else messageLocalizer:convertLiteral($locale,'form.terminology.button.no')" />
					</xsl:call-template>
				</fo:block>
			<xsl:if test="$sectionRoot/p:JOINT_PROCUREMENT_INVOLVED">
				<fo:block xsl:use-attribute-sets="h3"  margin-top="2mm">
					<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_contracting_authority.header.notice.national.procurement.law')" />
				</fo:block>
				<fo:block xsl:use-attribute-sets="h3" font-weight="normal"  margin-top="2mm">
					<xsl:call-template name="writeSingleLineData"><xsl:with-param name="singleLineData" select="$sectionRoot/p:PROCUREMENT_LAW" /></xsl:call-template>	
				</fo:block>	
			</xsl:if>
				<fo:block xsl:use-attribute-sets="h3"  margin-top="2mm">
					<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_contracting_authority.header.notice.contract.awarded.central')" />
				</fo:block>
				<fo:block xsl:use-attribute-sets="h3" font-weight="normal"  margin-top="2mm">
					<xsl:call-template name="writeSingleLineData">
						<xsl:with-param name="singleLineData" select="
							if( $sectionRoot/p:CENTRAL_PURCHASING ) then messageLocalizer:convertLiteral($locale,'form.terminology.button.yes')
							else messageLocalizer:convertLiteral($locale,'form.terminology.button.no')" />
					</xsl:call-template>
				</fo:block>
			</fo:block-container>
		</fo:block-container>			

		<xsl:if test="($noticeType='PRIOR_INFORMATION') or ($noticeType='CONTRACT')">
			<fo:block-container keep-together.within-page="auto">
				<fo:block xsl:use-attribute-sets="h2" >
					<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_contracting_authority.header.notice.communication')" />
				</fo:block>
				<fo:block-container xsl:use-attribute-sets="subSectionBox">
					<xsl:if test="($PinType='PRI_REDUCING_TIME_LIMITS') or ($PinType='PRI_CALL_COMPETITION') or ($noticeType='CONTRACT')">
						<fo:block xsl:use-attribute-sets="h3"  margin-top="2mm">
							<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_contracting_authority.header.notice.procurement.documents')" />
						</fo:block>
						<xsl:if test="$sectionRoot/p:DOCUMENT_FULL">
							<fo:block xsl:use-attribute-sets="h3" font-weight="normal"  margin-top="2mm">
								<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_ca.procurement.documents.unrestricted')" />
							</fo:block>
							<fo:block xsl:use-attribute-sets="h3" font-weight="normal"  margin-top="2mm">
								<xsl:call-template name="writeSingleLineData">
									<xsl:with-param name="singleLineData" select="$sectionRoot/p:URL_DOCUMENT" />
								</xsl:call-template>
							</fo:block>
						</xsl:if>
						<xsl:if test="$sectionRoot/p:DOCUMENT_RESTRICTED">
							<fo:block xsl:use-attribute-sets="h3" font-weight="normal"  margin-top="2mm">
								<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_ca.procurement.documents.restricted')" />
							</fo:block>
							<fo:block xsl:use-attribute-sets="h3" font-weight="normal"  margin-top="2mm">
								<xsl:call-template name="writeSingleLineData">
									<xsl:with-param name="singleLineData" select="$sectionRoot/p:URL_DOCUMENT" />
								</xsl:call-template>
							</fo:block>
						</xsl:if>
					</xsl:if>
					<xsl:if test="$sectionRoot/p:ADDRESS_FURTHER_INFO_IDEM">
						<fo:block xsl:use-attribute-sets="h3"  margin-top="2mm">
							<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_contracting_authority.header.notice.further.information.can.be.obtained.at')" />
						</fo:block>
						<fo:block xsl:use-attribute-sets="h3" font-weight="normal"  margin-top="2mm">
							<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_ca.above.mentioned.contact')" />
						</fo:block>
					</xsl:if>
					<xsl:if test="($PinType='PRI_REDUCING_TIME_LIMITS') or ($PinType='PRI_CALL_COMPETITION') or ($noticeType='CONTRACT')">
						<xsl:if test="$sectionRoot/p:URL_PARTICIPATION">
							<fo:block xsl:use-attribute-sets="h3" font-weight="normal"  margin-top="2mm">
								<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_contracting_authority.header.notice.electronic.communication.for.tender.request')" />
							</fo:block>
							<fo:block xsl:use-attribute-sets="h3" font-weight="normal"  margin-top="2mm">
								<xsl:call-template name="writeSingleLineData">
									<xsl:with-param name="singleLineData" select="$sectionRoot/p:URL_PARTICIPATION" />
								</xsl:call-template>
							</fo:block>
						</xsl:if>
						<xsl:if test="$sectionRoot/p:ADDRESS_PARTICIPATION_IDEM">
							<fo:block xsl:use-attribute-sets="h3"  margin-top="2mm">
								<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_contracting_authority.header.notice.tenders.or.requests.to.participate.must.be.sent.to')" />
							</fo:block>
							<fo:block xsl:use-attribute-sets="h3" font-weight="normal"  margin-top="2mm">
								<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_ca.above.mentioned.contact')"/>
							</fo:block>	
						</xsl:if>
					</xsl:if>
					<xsl:if test="$sectionRoot/p:URL_TOOL">
						<fo:block xsl:use-attribute-sets="h3" font-weight="normal"  margin-top="2mm">
							<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_contracting_authority.header.notice.electronic.communication')" />
						</fo:block>
						<fo:block xsl:use-attribute-sets="h3" font-weight="normal"  margin-top="2mm">
							<xsl:call-template name="writeSingleLineData">
								<xsl:with-param name="singleLineData" select="$sectionRoot/p:URL_TOOL" />
							</xsl:call-template>
						</fo:block>
					</xsl:if>
					<fo:block xsl:use-attribute-sets="h3" >
						<xsl:value-of select="''" />
					</fo:block>
				</fo:block-container>
			</fo:block-container>
		</xsl:if>
		
		<xsl:if test="$sectionRoot/p:ADDRESS_FURTHER_INFO">
			<fo:block xsl:use-attribute-sets="h2" >
				<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_contracting_authority.header.notice.further.information.can.be.obtained.from.another.address')" />
			</fo:block>
			<xsl:call-template name="writeContactDetails">
				<xsl:with-param name="contextNode" select="$sectionRoot/p:ADDRESS_FURTHER_INFO" />
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="$sectionRoot/p:ADDRESS_PARTICIPATION">
			<fo:block xsl:use-attribute-sets="h2" >
				<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_contracting_authority.header.notice.tenders.or.requests.to.participate.must.be.sent.to.the.following.address')" />
			</fo:block>
			<xsl:call-template name="writeContactDetails">
				<xsl:with-param name="contextNode" select="$sectionRoot/p:ADDRESS_PARTICIPATION" />
			</xsl:call-template>
		</xsl:if>			

		<fo:block-container keep-together.within-page="auto">
			<fo:block xsl:use-attribute-sets="h2" >
				<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_ca.type.of.ca.separator')" />
			</fo:block>
			<fo:block-container xsl:use-attribute-sets="subSectionBox">
				<fo:block xsl:use-attribute-sets="h3"  margin-top="2mm">
					<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_contracting_authority.header.notice.type.of.contracting.authority')" />
				</fo:block>
				<fo:block xsl:use-attribute-sets="h3" font-weight="normal"  margin-top="2mm">
					<xsl:call-template name="writeSingleLineData">
						<xsl:with-param name="singleLineData" select="
							if( $sectionRoot/p:CA_TYPE/@VALUE ) then $sectionRoot/p:CA_TYPE/@DESCRIPTION
							else if ( $sectionRoot/p:CA_TYPE_OTHER ) then concat( 'Other : ', $sectionRoot/p:CA_TYPE_OTHER)
							else ''" />
					</xsl:call-template>
				</fo:block>		
			</fo:block-container>
		</fo:block-container>
		
		<fo:block-container keep-together.within-page="auto">	
			<fo:block xsl:use-attribute-sets="h2" >
				<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_contracting_authority.header.notice.main.activity')" />
			</fo:block>
			<fo:block-container xsl:use-attribute-sets="subSectionBox">		
				<fo:block xsl:use-attribute-sets="h3"  margin-top="2mm">
					<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_contracting_authority.header.notice.main.activity.label')" />
				</fo:block>
				<fo:block xsl:use-attribute-sets="h3" font-weight="normal"  margin-top="2mm">
					<xsl:call-template name="writeSingleLineData">
						<xsl:with-param name="singleLineData" select="
							if( $sectionRoot/p:CA_ACTIVITY/@VALUE ) then $sectionRoot/p:CA_ACTIVITY/@DESCRIPTION
							else if ( $sectionRoot/p:CA_ACTIVITY_OTHER ) then concat( 'Other : ', $sectionRoot/p:CA_ACTIVITY_OTHER)
							else ''" />
					</xsl:call-template>
				</fo:block>						
			</fo:block-container>
		</fo:block-container>
	</xsl:template>

	<xsl:template name="Section_ContractingAuthority_CORRIGENDUM" >
		<xsl:param name="sectionRoot" />
		<xsl:param name="noticeRoot" />
		<!--<xsl:variable name="root" select="$sectionRoot/p:ADDRESS_CONTRACTING_BODY" />-->
		<xsl:variable name="noticeNumberAndPublicationDateRoot" select="$noticeRoot/p:OJ_NUMBER_AFTER_PUBLISH"/>
	
			<!--  Section Title -->
		<fo:block xsl:use-attribute-sets="h1">
			<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.noticetree.contracting_authority')" />
		</fo:block>
		
		<fo:block xsl:use-attribute-sets="h2">
			<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_contracting_authority.header.notice.name.address.and.contact.point')" />
		</fo:block>
		
		<xsl:call-template name="writeContactDetails">
			<xsl:with-param name="contextNode" select="$sectionRoot/p:ADDRESS_CONTRACTING_BODY" />
		</xsl:call-template>
		
		<xsl:for-each select="$sectionRoot/p:ADDRESS_CONTRACTING_BODY_ADDITIONAL"> 
			<fo:block xsl:use-attribute-sets="h2">
				<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_contracting_authority.header.notice.name.address.and.contact.point')" />
			</fo:block>
			<xsl:call-template name="writeContactDetails">
				<xsl:with-param name="contextNode" select="." />
			</xsl:call-template>
		</xsl:for-each>
	</xsl:template>	
</xsl:stylesheet>
