<!--
 (C) COPYRIGHT International Business Machines Corp. 2012, 2016. All Rights Reserved
  US Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-->
<xsl:stylesheet xmlns:p="ted/R2.0.9.S02/reception" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:fo="http://www.w3.org/1999/XSL/Format"
	xmlns:messageLocalizer="java:com.emptoris.app.ojeu.integration.PDFMessageLocalizer"
	version="2.0" xmlns:saxon="http://saxon.sf.net/" xmlns:emptoris-ojeu="http://www.emptoris.com/sourcing/ojeu"  extension-element-prefixes="saxon"
	>
	<!--
		In SAXON 8.3, only global variables can be marked as assignable. It'd be nice if local variables as assignable. Need
		to investigate further with SAXON.
	-->
	<xsl:include href="com/emptoris/app/ojeu/integration/NoticeToPDF-fop-AnnexB.xsl" />
	
	<xsl:template name="Section_ObjectOfContract">
		<xsl:param name="sectionRoot" />
		<xsl:param name="PinType" />
		<xsl:param name="noticeType" />
		<xsl:param name="contractType" />
		<xsl:param name="procedureType" />
		<xsl:if test="($noticeType !='CORRIGENDUM')">
			<xsl:call-template name="Section_ObjectOfContract_NOT_CORRIGENDUM" >
				<xsl:with-param name="sectionRoot" select="$sectionRoot" />
				<xsl:with-param name="PinType" select="$PinType" />
				<xsl:with-param name="noticeType" select="$noticeType" />
				<xsl:with-param name="contractType" select="$contractType" />
				<xsl:with-param name="procedureType" select="$procedureType" />
			</xsl:call-template>	
		</xsl:if>
		<xsl:if test="($noticeType ='CORRIGENDUM')">
			<xsl:call-template name="Section_ObjectOfContract_CORRIGENDUM" >
				<xsl:with-param name="sectionRoot" select="$sectionRoot" />
			</xsl:call-template>	
		</xsl:if>
	</xsl:template>		
	
	<xsl:template name="Section_ObjectOfContract_NOT_CORRIGENDUM">
		<xsl:param name="sectionRoot" />
		<xsl:param name="PinType" />
		<xsl:param name="noticeType" />
		<xsl:param name="contractType" />
		<xsl:param name="procedureType" />
		
		<xsl:variable name="contracts" select="$sectionRoot" />
		
		<xsl:for-each select="$contracts">
		<xsl:variable name="objectOfContract" select="." />
	
			<fo:block xsl:use-attribute-sets="h1">
				<xsl:value-of select="
				if( last() > 1 ) then concat(messageLocalizer:convertLiteral($locale,'form.noticetree.object_of_contract'),' (',position(),') ') 
				else messageLocalizer:convertLiteral($locale,'form.noticetree.object_of_contract') 
				" />
			</fo:block>
			
			<fo:block xsl:use-attribute-sets="h2">
				<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_object_of_contract.pin.header.scopeOfProcurement')" />
			</fo:block>
			
			<fo:block xsl:use-attribute-sets="h2">
				<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_object_of_contract.pin.works.header.title')" />
			</fo:block>
		
			<fo:block-container xsl:use-attribute-sets="subSectionBox">
				<fo:block xsl:use-attribute-sets="h3"  margin-top="2mm">
					<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_object_of_contract.pin.works.field.title')" />
				</fo:block>
				<xsl:call-template name="writeSingleLineData">
					<xsl:with-param name="singleLineData" select="p:TITLE" />
				</xsl:call-template>
				<fo:block xsl:use-attribute-sets="h3"  margin-top="2mm">
					<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_object_of_contract.pin.field.referenceNumber')" />
				</fo:block>
				<xsl:call-template name="writeSingleLineData">
					<xsl:with-param name="singleLineData" select="p:REFERENCE_NUMBER" />
				</xsl:call-template>
			</fo:block-container>
			
			
			<fo:block xsl:use-attribute-sets="h2">
				<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_object_of_contract.pin.header.mainCPVCode')" />
			</fo:block>
			<xsl:call-template name="writeMainCPVAndVOCTable">
				<xsl:with-param name="cpvNode" select="p:CPV_MAIN" />
				<!--<xsl:with-param name="headerTitle" select="CPV" />-->
			</xsl:call-template>
			
			<fo:block xsl:use-attribute-sets="h2">
				<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_object_of_contract.pin.header.typeOfContract')" />
			</fo:block>
			<fo:block-container xsl:use-attribute-sets="subSectionBox">
				<fo:block xsl:use-attribute-sets="h3"  margin-top="2mm">
						<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_object_of_contract.pin.field.typeOfContract')" />
				</fo:block>
				<xsl:call-template name="writeSingleLineData">
					<xsl:with-param name="singleLineData" select="p:TYPE_CONTRACT/@CTYPE" />
				</xsl:call-template>
			</fo:block-container>
			
			<fo:block xsl:use-attribute-sets="h2">
				<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_object_of_contract.pin.header.shortDescription')" />
			</fo:block>
			<fo:block-container xsl:use-attribute-sets="subSectionBox">
				<xsl:call-template name="writeMultiLineData">
					<xsl:with-param name="multiLineData" select="p:SHORT_DESCR" />
					<xsl:with-param name="marginLeft" select="'0mm'" />
				</xsl:call-template>
			</fo:block-container>
			
			<xsl:if test="($noticeType != 'CONTRACT_AWARD')">
				<fo:block xsl:use-attribute-sets="h2">
					<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_object_of_contract.pin.header.estimatedTotalValue')" />
				</fo:block>
				<fo:block-container xsl:use-attribute-sets="subSectionBox">
					<fo:block xsl:use-attribute-sets="h3"  margin-top="2mm">
							<xsl:value-of select="messageLocalizer:convertLiteral($locale,'ojeu.form.detail.contract_award.main_hdr.likely_to_subcontracted.vat')" />
					</fo:block>
					<xsl:call-template name="writeSingleLineData">
						<xsl:with-param name="singleLineData" select="concat(p:VAL_ESTIMATED_TOTAL, ' ', p:VAL_ESTIMATED_TOTAL/@CURRENCY)" />
					</xsl:call-template>
				</fo:block-container>
			</xsl:if>
			
			<fo:block xsl:use-attribute-sets="h2">
				<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_object_of_contract.pin.header.infoAboutLots')" />
			</fo:block>
			<fo:block-container xsl:use-attribute-sets="subSectionBox">
				<fo:block xsl:use-attribute-sets="h3"  margin-top="2mm">
						<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_object_of_contract.lotsdivision.header')" />
				</fo:block>
				<xsl:call-template name="writeSingleLineData">
					<xsl:with-param name="singleLineData" select="if( p:LOT_DIVISION ) then messageLocalizer:convertLiteral($locale,'form.terminology.button.yes')
							else if (p:NO_LOT_DIVISION)then messageLocalizer:convertLiteral($locale,'form.terminology.button.no')
							else ''" />
				</xsl:call-template>
				<xsl:if test="p:LOT_DIVISION">
					<xsl:if test="(p:LOT_DIVISION/p:LOT_ALL) or (p:LOT_DIVISION/p:LOT_ONE_ONLY) or (p:LOT_DIVISION/p:LOT_MAX_NUMBER)">
						<fo:block xsl:use-attribute-sets="h3"  margin-top="2mm">
							<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_object_of_contract.lots.tendersSubmittedFor')" />
						</fo:block>
						<xsl:call-template name="writeSingleLineData">
							<xsl:with-param name="singleLineData" select="if( p:LOT_DIVISION/p:LOT_ALL ) then messageLocalizer:convertLiteral($locale,'form.wiz_object_of_contract.lots.tendersSubmittedFor.allLots')
									else if (p:LOT_DIVISION/p:LOT_ONE_ONLY)then messageLocalizer:convertLiteral($locale,'form.wiz_object_of_contract.lots.tendersSubmittedFor.oneLotOnly')
									else if (p:LOT_DIVISION/p:LOT_MAX_NUMBER)then concat (messageLocalizer:convertLiteral($locale,'form.wiz_object_of_contract.lots.tendersSubmittedFor.maxNoOfLots'), ' ', p:LOT_DIVISION/p:LOT_MAX_NUMBER)
									else ''" />
						</xsl:call-template>
					</xsl:if>
					<xsl:if test="p:LOT_DIVISION/p:LOT_MAX_ONE_TENDERER">
						<xsl:call-template name="writeSingleLineData">
							<xsl:with-param name="singleLineData" select="if (p:LOT_DIVISION/p:LOT_MAX_ONE_TENDERER)then concat (messageLocalizer:convertLiteral($locale,'form.wiz_object_of_contract.lots.tendersSubmittedFor.maxNoOfLotsAWDToOneTenderer'), ' ', p:LOT_DIVISION/p:LOT_MAX_ONE_TENDERER)
									else ''" />
						</xsl:call-template>
					</xsl:if>
					<xsl:if test="p:LOT_DIVISION/p:LOT_COMBINING_CONTRACT_RIGHT">
						<xsl:call-template name="writeSingleLineData">
							<xsl:with-param name="singleLineData" select="if (p:LOT_DIVISION/p:LOT_COMBINING_CONTRACT_RIGHT)then  messageLocalizer:convertLiteral($locale,'form.wiz_object_of_contract.lots.tendersSubmittedFor.contractingAuthorityReserves')
									else ''" />
						</xsl:call-template>
							<xsl:call-template name="writeMultiLineData">
							<xsl:with-param name="multiLineData" select="p:LOT_DIVISION/p:LOT_COMBINING_CONTRACT_RIGHT" />
							<xsl:with-param name="marginLeft" select="'0mm'" />
						</xsl:call-template>
					</xsl:if>
				</xsl:if>
			</fo:block-container>
			
			<xsl:if test="($noticeType = 'CONTRACT_AWARD') and ((p:VAL_TOTAL) or (p:VAL_RANGE_TOTAL))">
				<fo:block xsl:use-attribute-sets="h2">
					<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_object_of_contract.award.finalValue.header')" />
				</fo:block>
				<fo:block-container xsl:use-attribute-sets="subSectionBox">
					<fo:block xsl:use-attribute-sets="h3"  margin-top="2mm">
							<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_object_of_contract.award.finalValue.field')" />
					</fo:block>
					<xsl:call-template name="writeSingleLineData">
						<xsl:with-param name="singleLineData" select="if (p:VAL_TOTAL)then  concat(messageLocalizer:convertLiteral($locale,'ojeu.form.detail.contract_award.hdr.total_final_value_hdr_value'), ' ', p:VAL_TOTAL, ' ', p:VAL_TOTAL/@CURRENCY) 
						else if (p:VAL_RANGE_TOTAL) then messageLocalizer:convertLiteral($locale,'pdf.notice.amount.minMax.range.Closed',(p:VAL_RANGE_TOTAL/p:LOW,p:VAL_RANGE_TOTAL/p:HIGH,p:VAL_RANGE_TOTAL/@CURRENCY))
									else ''" />
					</xsl:call-template>
				</fo:block-container>
			</xsl:if>
			
			<xsl:if test="($PinType='PRI_REDUCING_TIME_LIMITS')or ($PinType='PRI_ONLY')">
				<fo:block xsl:use-attribute-sets="h2">
					<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_object_of_contract.pin.header.dateOfPubContractNotice')" />
				</fo:block>
				<fo:block-container xsl:use-attribute-sets="subSectionBox">
					<fo:block xsl:use-attribute-sets="h3"  margin-top="2mm">
							<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_object_of_contract.pin.field.dateOfPubContractNotice')" />
					</fo:block>
					<xsl:call-template name="writeSingleLineData">
						<xsl:with-param name="singleLineData" select="p:DATE_PUBLICATION_NOTICE" />
					</xsl:call-template>
				</fo:block-container>
			</xsl:if>

			<fo:block-container break-before="page">			
			<xsl:variable name="lots" select="p:OBJECT_DESCR" />
			<xsl:for-each select="$lots">
			<xsl:call-template name="Section_AnnexB">
				<xsl:with-param name="objectOfContract" select="$objectOfContract"/>
				<xsl:with-param name="PinType" select="$PinType"/>
				<xsl:with-param name="noticeType" select="$noticeType"/>
				<xsl:with-param name="contractType" select="$contractType"/>
				<xsl:with-param name="procedureType" select="$procedureType"/>
				<xsl:with-param name="lotSection" select="." />
				<!--<xsl:with-param name="lotPosition" select="position()" />-->
			</xsl:call-template>
			<fo:block xsl:use-attribute-sets="h3" break-before="page">
				<xsl:value-of select="''" />
			</fo:block>
			</xsl:for-each>
			<fo:block xsl:use-attribute-sets="h3">
				<xsl:value-of select="''" />
			</fo:block>
			</fo:block-container>
		</xsl:for-each>	
	</xsl:template>
	
	<xsl:template name="Section_ObjectOfContract_CORRIGENDUM">
		<xsl:param name="sectionRoot" />
		<fo:block-container break-after="page">
			<fo:block xsl:use-attribute-sets="h1">
				<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.noticetree.object_of_contract')" />
			</fo:block>
			
			<fo:block xsl:use-attribute-sets="h2">
				<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_object_of_contract.pin.header.scopeOfProcurement')" />
			</fo:block>
			
			<fo:block xsl:use-attribute-sets="h2">
				<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_object_of_contract.pin.works.header.title')" />
			</fo:block>
		
			<fo:block-container xsl:use-attribute-sets="subSectionBox">
				<fo:block xsl:use-attribute-sets="h3"  margin-top="2mm">
					<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_object_of_contract.pin.works.field.title')" />
				</fo:block>
				<xsl:call-template name="writeSingleLineData">
					<xsl:with-param name="singleLineData" select="$sectionRoot/p:TITLE" />
				</xsl:call-template>
				<fo:block xsl:use-attribute-sets="h3"  margin-top="2mm">
					<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_object_of_contract.pin.field.referenceNumber')" />
				</fo:block>
				<xsl:call-template name="writeSingleLineData">
					<xsl:with-param name="singleLineData" select="$sectionRoot/p:REFERENCE_NUMBER" />
				</xsl:call-template>
			</fo:block-container>
			
			
			<fo:block xsl:use-attribute-sets="h2">
				<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_object_of_contract.pin.header.mainCPVCode')" />
			</fo:block>
			<xsl:call-template name="writeMainCPVAndVOCTable">
				<xsl:with-param name="cpvNode" select="$sectionRoot/p:CPV_MAIN" />
				<!--<xsl:with-param name="headerTitle" select="CPV" />-->
			</xsl:call-template>
			
			<fo:block xsl:use-attribute-sets="h2">
				<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_object_of_contract.pin.header.typeOfContract')" />
			</fo:block>
			<fo:block-container xsl:use-attribute-sets="subSectionBox">
				<fo:block xsl:use-attribute-sets="h3"  margin-top="2mm">
						<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_object_of_contract.pin.field.typeOfContract')" />
				</fo:block>
				<xsl:call-template name="writeSingleLineData">
					<xsl:with-param name="singleLineData" select="$sectionRoot/p:TYPE_CONTRACT/@CTYPE" />
				</xsl:call-template>
			</fo:block-container>
			
			<fo:block xsl:use-attribute-sets="h2">
				<xsl:value-of select="messageLocalizer:convertLiteral($locale,'form.wiz_object_of_contract.pin.header.shortDescription')" />
			</fo:block>
			<fo:block-container xsl:use-attribute-sets="subSectionBox">
				<xsl:call-template name="writeMultiLineData">
					<xsl:with-param name="multiLineData" select="$sectionRoot/p:SHORT_DESCR" />
					<xsl:with-param name="marginLeft" select="'0mm'" />
				</xsl:call-template>
			</fo:block-container>
		</fo:block-container>	
	</xsl:template>
</xsl:stylesheet>
